******************************
******************************
** ML Nigeria
** A1 - Data Preparation
******************************
******************************

/*
	READ ME
		set directory line 21
*/

capture log close
clear all
set more off
version 14.1
set matsize 11000 

*set directory
cd 

*Online codebook:
*http://microdata.worldbank.org/index.php/catalog/2329/data_dictionary

************************
* Data information
************************

/*
	
	Response rate:
	74% follow-up 1
	89% follow-up 2
	83% follow-up 3
	79% follow-up 4
	
	*Prefix:
	m_ 	first round
	s_ 	second round
	t_ 	third round
	o_ 	outcome variable
 	p_ 	predictor
	b_ 	predictor from business plan 
	su_	selected variables for logit 

*/
	
************************
* Merge and load Data
************************

	*Baseline and First Follow up
	use "Raw\AERReplicationVersion\BaselineandFirstFollowup.dta", clear
	
		*check that uid perfectly identifies firms
		duplicates list uid
		
		*sample composition
		count
		*3,139 of which
		*475 
			*individuals selected as national or zonal winners of the competition, based on having the highest absolute scores on their business plans, 
			*or highest scores for their region. These are referred to as the national and zonal winner sample. 
			*Note this consists of all national and zonal winners except for the 5 disqualified plans.
		*729 
			*individuals who were selected as ordinary winners of the competition through a random draw among individuals with the next highest scores. 
			*These are referred to as the experimental treatment sample. 
			*This does include individuals originally allocated to treatment who were subsequently disqualified.
		*1,112 
			*individuals who had similar business plan scores as the ordinary winners, but were not selected in the random draw.
			*These are referred to as the experimental control sample. Note 9 of these actually received treatment.
		*823 
			*individuals who applied for the YouWiN! competition and had first round application scores just on either side of the cut-offs used 
			*to select people to attend the 4-day business plan training course. 
			*This group is referred to as the regression-discontinuity booster sample.
		di 475+729+1112+823
		* = 3139 as expected
		
	*Merge with Second Follow-Up
	merge 1:1 uid using "Raw\AERReplicationVersion\SecondFollowup.dta", nogen sorted
	*all matched
	
	*Merge with Third Follow-Up
	merge 1:1 uid using "Raw\AERReplicationVersion\ThirdFollowup.dta", nogen sorted
	*all matched

	*Merge with region for RD
	merge 1:1 uid using "Raw\AERReplicationVersion\regionuid.dta", sorted
	*_me==1 ok since some obs are not in the RD sample
	*_me==2 can be dropped
	drop if _me==2
	drop _me
	count
	*3139

	*Merge with variables from non-public dataset
	merge 1:1 uid using "Raw\VariablesRestrictedData.dta", nogen
	*647 not matched
	*2492 (+624 RD dropped + 9 control with aid +14 disqualified= 3139)
	
************************
* NOTE: Drop firms without business plan scores from RD sample
************************	

	tab group if totalmarks==.
	*624
	*Only RD group, as expected
	drop if totalmarks==.

************************
* NOTE: Drop people in control group who actually recived award (9 firms)
************************	

	*gen indicator for people in control who actually received award (9 firms)
	gen controlaward = (group==2 & fa_totalawardpaid>0 & fa_totalawardpaid!=.)
	drop if controlaward==1
	
************************
* NOTE: Drop disqualified firms (14 firms)
************************	
	
	drop if disqualified==1

	*save merged data
	save "MLNigeria_masterdataraw.dta", replace
	
************************
* Create variables
************************

	use "MLNigeria_masterdataraw.dta", clear
	
	************************
	* Key Variables
	************************	

		*new
			*identifies "Is an application for a new business?"
		*existing
			*Is an application for an existing business?
			
		tab group, gen(p_group)
		*1: Experimental Winners 
		*2: Control Group
		*3: Non-experimental winners 
		*4: RD group 
	
	************************
	* Outcome Variables
	************************
	
		***
		*Survival
		***
	
			*Currently operate a firm at third follow-up
			*start with variable t_sc: Do you currently operate a business?
			*1 Yes
			*2 No
			gen o_t_operatefirm= (t_sc==1) if !missing(t_sc)
			*Replace missing if it is possible to get info from t_operate : do you currently operate a business?
			*1 Yes
			*2 No
			tab t_sc t_operate, m
			tab t_sc t_operate, m nol
			*1 Yes
			*2 No
			replace o_t_operatefirm=1 if o_t_operatefirm==. & t_operate==1
			replace o_t_operatefirm=0 if o_t_operatefirm==. & t_operate==2
			*Replace missing if the respondent owns a business as reported from the attrition section 
			*(filled only after interviewers failed to contact respondent)
			*t_a3: does the targeted respondent currently own a business?
			*1 Yes
			*2: No
			*3: DK
			replace o_t_operatefirm=1 if t_a3==1 & o_t_operatefirm==.
			replace o_t_operatefirm=0 if t_a3==2 & o_t_operatefirm==.
			
			*check
			*are all the missings due to attrition? YES
			codebook t_sc o_t_operatefirm
			count if t_sc==.
			local Ncheck = r(N)
			foreach var of varlist t_inttime-t_surveymonkey {
				capture confirm string variable `var' 
				if _rc!=0 {
				qui count if missing(`var')
					if r(N)<`Ncheck' {
						di `var'
						codebook `var'
						_exit
					}
				}	
			}
			
		***
		*Employment
		***
		
			*Wage or Salaried Workers
			*Third follow-up
			*start with t_ef3_1: 
				*Tell me how many of the following types of workers you currently have working in your business: 
				*[Do not count yourself in any of these categories]
				*1. Wage or Salaried Workers
			gen o_t_wagesalaryemps=t_ef3_1
			*don't know/can't say/refused to answer coded as 999, count as 0
			replace o_t_wagesalaryemps=0 if t_ef3_1==999
			*put as zero if firm is not running (so some missings become 0)
			replace o_t_wagesalaryemps=0 if o_t_operatefirm==0
			
			*Current number of casual or daily workers
			gen o_t_casualdaily=t_ef3_2
			*don't know/can't say/refused to answer coded as 999, count as 0
			replace o_t_casualdaily=0 if t_ef3_2==999
			*put as zero if firm is not running (so some missings become 0)
			replace o_t_casualdaily=0 if o_t_operatefirm==0
			
			*Overall employment including owner and casual workers
			*Missing if firm is not operating
			*note: rowtotal treats missing as 0
			egen o_t_totalemp1= rowtotal(o_t_operatefirm o_t_wagesalaryemps o_t_casualdaily) if !missing(o_t_operatefirm)
			*0 if the firm is not operating
			replace o_t_totalemp1=0 if o_t_operatefirm==0
			*0 changes
			*Look at total employment within dataset (t_ef3_5) + 1(for the owner) if totalempl is missing and the firm is running
			replace o_t_totalemp1= t_ef3_5 +1 if t_ef3_5<998 & o_t_totalemp1==. & o_t_operatefirm==1
			*0 changes
			*If still missing, look at t_a4: approximately how many employees does this business have?
			replace o_t_totalemp1=t_a4 if t_a4<998 & o_t_totalemp1==.
			*0 changes

			*Whether total employment is more than 10
			gen o_t_tenplus= (o_t_totalemp1>=10) if !missing(o_t_totalemp1)
			
			*IHS transformation
			gen o_t_totalemp1_IHS=log(o_t_totalemp1+((o_t_totalemp1^2+1)^(1/2)))
			*use Stata function
			*gen o_t_totalemp1_IHSb = asinh(o_t_totalemp1)
			*count if o_t_totalemp1_IHS!=o_t_totalemp1_IHSb
			*0
			
		***
		*Innovation
		***
	
			* Introduced a new product
			gen o_t_innovate1= (t_in1==1) if !missing(t_in1)
			* Improved existing service or product
			gen o_t_innovate2= (t_in8==1) if !missing(t_in8)
			* Introduced new or improved process
			gen o_t_innovate3= (t_in9==1) if !missing(t_in9)
			* Introduced new design or packaging
			gen o_t_innovate4= (t_in12_1==1) if !missing(t_in12_1)
			* Introduced new channel for selling goods
			gen o_t_innovate5= (t_in12_2==1) if !missing(t_in12_2)
			* Introduced new method for pricing goods
			gen o_t_innovate6= (t_in12_3==1) if !missing(t_in12_3)
			* Introduced new way of advertising
			gen o_t_innovate7= (t_in12_4==1) if !missing(t_in12_4)
			* Changed way work organized in firm
			gen o_t_innovate8= (t_in12_6==1) if !missing(t_in12_6)
			* Introduced new quality control standards
			gen o_t_innovate9= (t_in12_7==1) if !missing(t_in12_7)
			* Licensed a new technology
			gen o_t_innovate10= (t_in13_3==1) if !missing(t_in13_3)
			* Obtained new quality accreditation
			gen o_t_innovate11= (t_in13_6==1) if !missing(t_in13_6)
			* Uses internet
			gen o_t_innovate12= (t_in15==1) if !missing(t_in15)

			* replace with zeros if firm closed
			foreach var in 	o_t_innovate1 o_t_innovate2 o_t_innovate3 o_t_innovate4 o_t_innovate5 o_t_innovate6 o_t_innovate7 o_t_innovate8 ///
							o_t_innovate9 o_t_innovate10 o_t_innovate11 o_t_innovate12 {
			replace `var'=0 if o_t_operatefirm==0
			}

			* Innovation index
			egen o_t_innovateindex = rowmean(o_t_innovate1-o_t_innovate12)
			
		***
		*Sales
		***			
 
			*Total sales in last month with no truncation
			gen o_t_sales=t_bf5
			*DK as 0
			replace o_t_sales=0 if o_t_sales==998
			*0 if firm is not operating
			replace o_t_sales=0 if o_t_operatefirm==0
			
			*Log sales
			gen o_t_sales_log = log(o_t_sales) if o_t_sales>0 & !missing(o_t_sales)
			replace o_t_sales_log = 0  if o_t_sales==0
			
			*IHS transformation
			*see formula at https://robjhyndman.com/hyndsight/transformations/
			*theta == 1
			gen o_t_sales_IHS=log(o_t_sales+((o_t_sales^2+1)^(1/2)))

		***
		*Profits
		***		
		
			*Total profits in last month with no truncations
			gen o_t_profits=t_bf9
			*DK as 0
			replace o_t_profits=0 if o_t_profits==998
			*0 if firm is not operating
			replace o_t_profits=0 if o_t_operatefirm==0	
			
			*Log profits
			gen o_t_profits_log = log(o_t_profits) if o_t_profits>0 & !missing(o_t_profits)
			replace o_t_profits_log = 0  if o_t_profits==0
			
			*IHS transformation
			gen o_t_profits_IHS=log(o_t_profits+((o_t_profits^2+1)^(1/2)))			
			
		***
		*Standardized z-score
		***			
			
			foreach var of varlist o_t_totalemp1 o_t_sales o_t_profits {
			  sum `var' 
			  gen `var'_z=(`var'-r(mean))/(r(sd))
			  } 	
			
	************************
	* Predictors - Baseline
	************************

		******
		* Demographics
		******
		
			*gender
			gen p_female= (sex=="Female") if !missing(sex)
			* if sex missing, impute values from variable female: Owner is Female
			replace p_female = female if missing(p_female)
			*no missing values left
			
			*Age (between 18 and 80, although second largest is 45. mean is 30)
			*never missing
			gen p_age = age
			*sum age, d
			*One guy says 80, well above the limit, top-code it at 45
			replace p_age = 45 if p_age>45 & !missing(p_age)
			*sum p_age, d
			
			*Education
			*What is your highest level of education completed?
			*only secondary education or lower
			gen p_seceduc = highschooledn 
				*If missing, take info from wave 1
				replace p_seceduc = 1 if m_p6==1 & p_seceduc==.
				replace p_seceduc = 1 if m_p6==2 & p_seceduc==.
				replace p_seceduc = 0 if m_p6==3 & p_seceduc==.
				replace p_seceduc = 0 if m_p6==4 & p_seceduc==.
				replace p_seceduc = 0 if m_p6==5 & p_seceduc==.
			*Post-secondary school vocational training/OND/Technical colleges
			gen p_techeduc = polytechnic 
				*If missing, take info from wave 1
				replace p_techeduc = 0 if m_p6==1 & p_techeduc==.
				replace p_techeduc = 0 if m_p6==2 & p_techeduc==.
				replace p_techeduc = 1 if m_p6==3 & p_techeduc==.
				replace p_techeduc = 0 if m_p6==4 & p_techeduc==.
				replace p_techeduc = 0 if m_p6==5 & p_techeduc==.
			*University/HND degree
			gen p_tereduc = university
				*If missing, take info from wave 1
				replace p_tereduc = 0 if m_p6==1 & p_tereduc==.
				replace p_tereduc = 0 if m_p6==2 & p_tereduc==.
				replace p_tereduc = 0 if m_p6==3 & p_tereduc==.
				replace p_tereduc = 1 if m_p6==4 & p_tereduc==.
				replace p_tereduc = 0 if m_p6==5 & p_tereduc==.			
			*Post graduate degree
			gen p_higheduc = postgraduate
				*If missing, take info from wave 1
				replace p_higheduc = 0 if m_p6==1 & p_higheduc==.
				replace p_higheduc = 0 if m_p6==2 & p_higheduc==.
				replace p_higheduc = 0 if m_p6==3 & p_higheduc==.
				replace p_higheduc = 0 if m_p6==4 & p_higheduc==.
				replace p_higheduc = 1 if m_p6==5 & p_higheduc==.			
			*No missings
			*count if p_seceduc==.
			*count if p_techeduc==.
			*count if p_higheduc==.
			*count if p_tereduc==.
			*all zero
			*categorical variable
			gen p_educ = 1 if highschooledn==1
			replace p_educ = 2 if polytechnic==1
			replace p_educ = 3 if university==1
			replace p_educ = 4 if postgraduate==1
			*If missing, take info from wave 1
			replace p_educ = 1 if p_educ==. & m_p6==1
			replace p_educ = 1 if p_educ==. & m_p6==2
			replace p_educ = 2 if p_educ==. & m_p6==3
			replace p_educ = 3 if p_educ==. & m_p6==4
			replace p_educ = 4 if p_educ==. & m_p6==5
			*tab p_educ, m

			*create regional dummies
			generat region_intermediate = 1 if region=="North-Central"
			replace region_intermediate = 2 if region=="North-Eastern"
			replace region_intermediate = 3 if region=="North-Western"
			replace region_intermediate = 4 if region=="South-Eastern"
			replace region_intermediate = 5 if region=="South-South"
			replace region_intermediate = 6 if region=="South-Western"
			*if region missing, use region_numeric
			*tab region_numeric if region=="", m
			replace region_intermediate = region_numeric if region_intermediate==.
			*no missings
			tab region_intermediate, m gen(p_region)

			*Marital Status:
			*1 = Married or Living Together with a Partner
			*2 = Divorced/Separated
			*3 = Widowed
			*4 = Never Married and Never Lived Together
			*never missing
			gen p_married  = (marital_status==1) 
			gen p_divorced = (marital_status==2) 
			gen p_widowed  = (marital_status==3) 
			gen p_single   = (marital_status==4)
			
			*Family
			*Number children
			*codebook number_of_children number_of_brothers number_of_sisters  
			*never missing
			gen p_children = number_of_children
			*Siblings
			gen p_brother = number_of_brothers
			gen p_sister  = number_of_sisters  
			
			*Main language spoken at home
			tab main_language, m gen(p_lang)
			*English spoken at home
			*gen su_senglish = (main_language==4) if !missing(main_language)

			*Internal migrant
			*state_residence has no missings
			*state_origin has only two missings, so negligible and I think it is safe to assume that these two moved
			gen p_imigr = (state_origin!=state_residence)
			
		******
		* Experience
		******			
		
			*Before the You Win competition, have you ever attended a course which covers any of the following information?
			*codebook business_accounting_training marketing_training computer_skills vocational_training
			*never missing
			*Business accounting 
			gen p_btraining = business_accounting_training
			*Marketing
			gen p_mtraining = marketing_training
			*Computer skills 
			gen p_ctraining = computer_skills
			*Vocational training (e.g. training to be a hairdresser, builder, etc.)
			gen p_vtraining = vocational_training
			
			*Are you currently employed outside of your proposed business?
			gen p_oemploy = otherwise_employed  
			*If yes, part time or full time?
			*tab full_or_part_time otherwise_employed, m
			*0 for those not working outside the firm
			tab full_or_part_time, m gen(p_wtime)
			
			*Have you ever worked or studied abroad?
			*never missing
			gen p_workabroad = lived_worked_abroad
			*Years living abroad
			gen p_yworkabroad = years_lived_abroad
			*put as zero if missing and never lived abroad or claim to lived abroad but not specify number of years
			replace p_yworkabroad = 0  if missing(p_yworkabroad) & !missing(p_workabroad)
			
		******
		* Behavior
		******
		
			*risk
			*Original question: Imagine you are being offered a choice between a lottery which will pay you a prize of 5 million if you win, 
			*or receiving 1 million with certainty. 
			*For each of the following, tell us whether you would choose the lottery ticket or the certain amount:
				*For each they should answer 
				*1 = prefer lottery ticket, 
				*2 = prefer 1 million certain amount, 
				*3 = indifferent, 
				*4= don’t know
			*A lottery ticket which has a 10% chance of paying 5 million, vs receiving 1 million with certainty
			tab rate_lottery_ten_percent, m gen(p_lot10)
			*20% chance
			tab rate_lottery_twenty_percent, m gen(p_lot20)
			*30% chance
			tab rate_lottery_thirty_percent, m gen(p_lot30)
			*50% chance
			tab rate_lottery_fifty_percent, m gen(p_lot50)	
			*70% chance
			tab rate_lottery_seventy_percent, m gen(p_lot70)			
			*90% chance
			tab rate_lottery_ninety_percent, m gen(p_lot90)	
			*100% chance
			tab rate_lottery_hundred_percent, m gen(p_lot100)
			
			*We are interested in why you want to run your own business instead of being in salaried work. 
			*For each of the following, tell us how important it is for you wanting to run your own business rather than being employed for a salary
			*1 = Very important, 
			*2 = important, 
			*3 = somewhat important, 
			*4 = not important,
			*5 = don’t know 
			*6 = not applicable
			*a. The possibility to care for children or other family members while I work
			tab rate_care_for_family, m gen(p_care)
			*b. To be my own boss and not have to rely on others
			tab rate_independence , m gen(p_free)
			*c. Flexibility in hours of work
			tab rate_flexibility, m gen(p_flex)
			*d. The possibility to earn more money
			tab rate_greater_salary, m gen(p_moremon)
			*e. Difficulty in finding a wage job
			tab rate_employment, m gen(p_needjob)
			*f. The possibility that my business will grow in the future
			tab rate_possiblity_of_growth, m gen(p_growth)
			*g. Running my own business is less boring/more exciting than salary/wage work
			tab rate_excitement, m gen(p_excited)
			*motivation
			*codebook rate_care_for_family-rate_excitement
			*no missings
			qui pca rate_care_for_family-rate_excitement 
			qui predict p_motivation
			*necessity entrepreneurship
			gen p_needjob = (rate_employment==1 | rate_employment==2) if !missing(rate_employment)
			
			*How confident are you that you can carry out the following tasks:
			*1 = not at all confident, 
			*2 = somewhat confident, 
			*3 = quite confident, 
			*4 = very confident, 
			*5 = don’t know
			*6 = not applicable
			*a) Sell a new product or service to a new client
			tab rate_sales_skills, m gen(p_saskill)
			*b) Find and hire good employees to expand your business
			tab rate_recruitment_skills, m gen(p_reskill)
			*c) Obtain a good price for buying business inputs
			tab rate_bargaining_skills, m gen(p_baskill)
			*d) Persuade a bank to lend you Money to start your business
			tab rate_credit_rating, m gen(p_credrat)
			*e) Estimate accurately the costs of a new Project
			tab rate_cost_estimation, m gen(p_costest) 
			*f) Manage an employee who is not a family member
			tab rate_management_skills, m gen(p_maskill)
			*g) Correctly value your business if you wanted to sell it
			tab rate_accounting_skills, m gen(p_acskill)
			*h) Resolve a difficult dispute with a business client in another city
			tab rate_diplomatic_skills, m gen(p_diskill)
			*i) Identify when it is time to stop making or selling a product that is not selling well
			tab rate_business_sense, m gen(p_buskill)
			*self-confidence pca
			*codebook rate_sales_skills-rate_business_sense
			*no missings
			qui pca rate_sales_skills-rate_business_sense
			qui predict p_selfconf

			*registration time
			*codebook reg_time
			*no missings
			destring reg_time, gen(p_regtime) 
			gen p_lateentrant = p_regtime>1321657200 
			*gen lateentrant=p_regtime>1321657200 & p_regtime~=. 
			*count if p_lateentrant != lateentrant
			*0
			*epoch time
			*https://www.epochconverter.com/
			*Nigeria is GMT+1
			
		******
		* Assets
		******		
			
			*codebook have_internet have_agricultural have_sewing_machines-have_satellite_dishes
			*never missing
			*Internet
			gen p_internet 	 = (have_internet==1) 
			*Agricultural land
			gen p_land 	 = (have_agricultural==1)
			*Sewing machine
			gen p_sewing 	= have_sewing_machines  
			*Gas cooker
			gen p_gascook 	= have_gas_cookers 
			*Stove (electric)
			gen p_estove 	= have_electric_stoves 
			*Stove gas (table)
			gen p_gstove 	= have_gas_stoves 
			*Stove (kerosene)
			gen p_kstove 	= have_kerosene_stoves
			*Fridge
			gen p_fridge 	= have_fridges 
			*Freezer
			gen p_freezer 	= have_freezers
			*Air conditioner
			gen p_ac 		= have_air_cons 
			*Washing Machine
			gen p_washmach 	= have_washing_machines
			*Electric Clothes Dryer
			gen p_dryer 	= have_electric_clothes_driers 
			*Bicycle
			gen p_bike		= have_bicycles 
			*Motorbike
			gen p_motorbike	= have_motorcycles 
			*Cars and other vehicles
			gen p_car 		= have_cars_and_other_vehicles
			*Generator
			gen p_generator = have_genrators 
			*Hi-Fi (Sound System)
			gen p_hifi 		= have_hifis 
			*Microwave
			gen p_microwave = have_microwaves  
			*TV Set
			gen p_tv 		= have_televisions
			*Computer
			gen p_computer 	= have_computers 
			*DVD Player
			gen p_dvd 		= have_dvd_players
			*Satellite Dish
			gen p_satellite = have_satellite_dishes 
			*Wealth index
			qui pca have_sewing_machines-have_satellite_dishes
			qui predict p_wealthindex

		******
		* Business
		******		
		
			*business sector
			tab business_sector, m gen(p_sector)
			gen p_manuf = (business_sector>=30 & business_sector<=33) if !missing(business_sector)
			gen p_retail = (business_sector>=11 & business_sector<=15) if !missing(business_sector)

			*the following questions were asked only to existing firms at baseline
			
			*How many workers with the following qualifications does your business currently employ?
			*No education 
			gen p_nempln = workers_with_no_qualifications
			*Primary education 
			gen p_nemplp = workers_with_primary_education
			*Secondary education
			gen p_nempls = workers_with_secondary_education
			*Tertiary education
			gen p_nemplt = workers_with_tertiary_education
			
			*Is your business currently registered with the Corporate Affairs Commission (Yes / No)
			gen p_busreg = business_registered
			*If Yes, which of the following category best describes your business registration status:
			*Limited liability company
			*Business name
			*Other
			tab business_registration_status, m gen(p_bustype)
			
			*How much tax did you pay last year?
			gen p_taxpaid = tax_paid_last_year  
			
			*Does your business currently have a loan from any of the following? Yes/No
			* Bank
			gen p_lbank = loan_from_bank 
			* Microfinance organization
			gen p_lmicro = loan_from_microfinance_organisat 
			* Cooperative society
			gen p_lcoop = loan_from_cooperative  

			*A second measure relates to previous and current access to credit. 
			*This might be viewed as a signal of ability from formal or informal lenders. 
			*We combine responses to three questions: 
			*whether the owner has previously received a bank loan; 
			*whether the owner currently buys any inputs on credit (i.e., whether she/he receives trade credit from suppliers); 
			*and whether the owner says she/he would be able to borrow 5000 GhC from any source to invest in the business. 
			*Again we use discriminant analysis to extract a common factor.
			qui pca loan_from_bank loan_from_microfinance_organisat loan_from_cooperative
			qui predict p_creditfw
			
			*What are your major challenges to running your own business?
			*codebook lack_funding lack_skills lack_experience lack_interest
			*no missing
			*Lack of funds to start a business
			gen p_cfund = lack_funding
			*Lack of the required skills
			gen p_cskill = lack_skills
			*Lack of business experience
			gen p_cexp = lack_experience
			*Lack of interest in business
			gen p_cint = lack_interest
						
			*Expectations for existing firms
			*amount of money needed to expand
			gen p_f17 = f17_ga 
			*number of new people business will employ
			gen p_f18 = f18_ga
			*Projected annual turnover
			gen p_f19 = f19_ga
			
			*amount they sought in their business plan
			*p_mask generated from restricted data
			*amount they were going to contribute
			*p_mgive generated from restricted data

	************************
	* Predictors - First wave
	************************
	
		******
		* Personal information 
		******	

			*Imagine for a minute that you are living the best life you can possibly imagine. 
			*Now imagine that your life is the worst it could possibly be. Imagine a ladder with 10 steps. 
			*Suppose we say that the top of the ladder (step 10) represents the best possible life for you 
			*and the bottom (step 1) represents the worst possible life for you. 
			*Which step on the ladder best represents where you personally stand at the present time?
			tab m_p10, m gen(p_satisfd)
			gen p_satisf = m_p10
			
			*Think about your life five years from today. Which step best represents where you personally will be on the ladder five years from now?
			tab m_p11, m gen(p_satexpd)
			gen p_satexp = m_p11
			
			*Self-confidence
			*How confident are you in your ability to do each of the following:
			*1 = not at all confident, 2 = somewhat confident, 3 = confident, 4= very confident, 9 = no answer/refuse to answer
			*Come up with an idea for a new business product or service
			tab m_p12a, m gen(p_maconf)
			*Estimate accurately the costs of a new business venture
			tab m_p12b, m gen(p_mbconf)
			*Estimate customer demand for a new product or service
			tab m_p12c, m gen(p_mcconf)
			*Sell a product or service to a customer you are meeting for the first time
			tab m_p12d, m gen(p_mdconf)
			*Identify good employees who can help a business grow
			tab m_p12e, m gen(p_meconf)
			*Inspire, encourage, and motivate employees
			tab m_p12f, m gen(p_mfconf)
			*Find suppliers who will sell you raw materials at the best price
			tab m_p12g, m gen(p_mgconf)
			*Persuade a bank to lend you money to finance a business venture
			tab m_p12h, m gen(p_mhconf)
			*Correctly value a business if you were to buy an existing business from someone else
			tab m_p12i, m gen(p_miconf)
			*codebook m_p12a-m_p12i
			*there are missings
			qui pca m_p12a-m_p12i
			qui predict p_selfconfw1
	
	************************
	* Predictors - Second wave
	************************
	
		******
		* Personal information
		******	
		
			*Backward Digit-span Recall
			*I am now going to show you a card with several numbers written on it. I will show you the card for 10 seconds. 
			*I will then wait 10 seconds, and ask you to repeat the numbers back to me in reverse order.
			*Show them the card with 4 numbers on it for 10 seconds, then wait for 10 seconds, and ask them to repeat the numbers back to you in reverse order. 
			*If they get the numbers correct on the first attempt, mark 1 for correct in the box and move onto the next card with 5 numbers on it. 
			*Otherwise, if they do not get the numbers right, mark 2 for incorrect in the box, and move onto the next section.
			*4 Numbers
			gen p_4digit_m = missing(s_q13a) 
			gen p_4digit = (s_q13a==1)
			*5
			gen p_5digit = (s_q13b==1)
			*6
			gen p_6digit = (s_q13c==1)
			*7
			gen p_7digit = (s_q13d==1)
			*8
			gen p_8digit = (s_q13e==1)
			*9
			gen p_9digit = (s_q13f==1)
			*10
			gen p_10digit = (s_q13g==1)
			*11
			gen p_11digit = (s_q13h==1)
			*if the interview is being conducted over the phone, the interviewer should read the numbers slowly over the phone, 
			*and then ask the respondent to repeat back in reverse order.
			*Done over the phone
			gen p_pdigit = (s_q13==2) if !missing(s_q13)
			*Backward Digit-span Recall score
			gen p_digitspan=3 if s_q13a==2
			replace p_digitspan=4 if s_q13b==2
			replace p_digitspan=5 if s_q13c==2
			replace p_digitspan=6 if s_q13d==2
			replace p_digitspan=7 if s_q13e==2
			replace p_digitspan=8 if s_q13f==2
			replace p_digitspan=9 if s_q13g==2
			replace p_digitspan=10 if s_q13h==2
			replace p_digitspan=11 if s_q13h==1
			
			*Raven Test
			*This will only be able to be done for individuals interviewed in person, and will not be possible for phone interviews.
			*I will show you a series of pictures. Each picture has figures in two rows and three columns. One figure is missing. 
			*You should find the missing part required to complete a pattern. You will be given 5 minutes. During that time, do as many as possible. 
			*Feel free to skip a picture and come back later..
			*Create a dummy for each option, choosing a wrong option may still have a different impact than chooseing a different wrong one
			tab s_c1, m gen(p_rava)
			tab s_c2, m gen(p_ravb)
			tab s_c3, m gen(p_ravc)
			tab s_c4, m gen(p_ravd)
			tab s_c5, m gen(p_rave)
			tab s_c6, m gen(p_ravf)
			tab s_c7, m gen(p_ravg)
			tab s_c8, m gen(p_ravh)
			tab s_c9, m gen(p_ravi)
			tab s_c10, m gen(p_ravl)
			tab s_c11, m gen(p_ravm)
			tab s_c12, m gen(p_ravn)
			*Raven test score
			gen raven1=s_c1==8
			gen raven2=s_c2==2
			gen raven3=s_c3==3
			gen raven4=s_c4==8
			gen raven5=s_c5==7
			gen raven6=s_c6==4
			gen raven7=s_c7==5
			gen raven8=s_c8==1
			gen raven9=s_c9==7
			gen raven10=s_c10==6
			gen raven11=s_c11==1
			gen raven12=s_c12==2
			egen p_raven=rsum(raven1-raven12)
			replace p_raven=. if s_c1==.
			
			*Grit
			*1-very much like me
            *2-mostly like me
            *3-somewhat like me
            *4-not much like me
            *5-not like me at all
			*I have overcome setbacks to conquer an important challenge
			tab s_g1, m gen(p_grita)
			*New ideas and projects sometimes distract me from previous ones.
			tab s_g2, m gen(p_gritb)
			*My interests change from year to year.
			tab s_g3, m gen(p_gritc)
			*Setbacks don't discourage me.		
			tab s_g4, m gen(p_gritd)
			*I have been obsessed with a certain idea or project for a short time but later lost interest.
			tab s_g5, m gen(p_grite)
			*I am a hard worker.
			tab s_g6, m gen(p_gritf)
			*I often set a goal but later choose to pursue a different one.
			tab s_g7, m gen(p_gritg)
			*I have difficulty maintaining my focus on projects that take more than a few months to complete.
			tab s_g8, m gen(p_grith)
			*I finish whatever I begin.
			tab s_g9, m gen(p_griti)
			*I have achieved a goal that took years of work.
			tab s_g10, m gen(p_gritl)
			*I become interested in new pursuits every few months.
			tab s_g11, m gen(p_gritm)
			*I am diligent.
			tab s_g12, m gen(p_gritn)
			*Missing (one variable for all grit since they are missing all for the same)
			drop p_gritb6 p_gritc6 p_gritd6 p_grite6 p_gritf6 p_gritg6 p_grith6 p_griti6 p_gritl6 p_gritm6 p_gritn6
			*Grit
			gen p_grit=((6-s_g1)+s_g2+s_g3+(6-s_g4)+s_g5+(6-s_g6)+s_g7+s_g8+(6-s_g9)+(6-s_g10)+s_g11+(6-s_g12))/12
		
			* Ability index of digitspan and raven (as Meckenzie)
			qui pca p_raven p_digitspan
			qui predict p_ability

			*To measure ability, we combine five measures using discriminant analysis. 
			*The measures are: years of schooling; the score on a Raven nonverbal reasoning test; 
			*the maximum number of digits recalled on a digitspan recall test; 
			*successful recitation of the seventh number in the series counting backward from 100 by seven; 
			*and the score on a four-question test of financial literacy
			qui pca p_educ p_raven p_digitspan
			qui predict p_abilityfw
			
	******
	* Impute missings to zero
	******		
		
		*Not done for variables where I use tab to generate them since I already used the option m
			
		foreach var in 	oemploy nempln nemplp nempls nemplt busreg taxpaid lbank lmicro lcoop pdigit f17 f18 f19 ///
						grit raven digitspan ability abilityfw creditfw satisf satexp educ selfconfw1 {
				gen p_`var'_m = missing(p_`var')
				replace p_`var' = 0 if missing(p_`var')
		}

	******
	* Text analysis
	******	
		
		*Business name same as surname
		*The variable p_bussn has been generated from restricted data
		
		*Business name same as name  - loose definition
		*if surname in firm name, 1 as before
		*put as 1 if name in business name
		*check if name or surname in the business name as part of the firm name	
		*put as 1 if initials in business name
		*add part name/surname
		*put as 1 if substring in business name	
		*The variable p_bussnb has been generated from restricted data				

		*Business name -  strdist, then take min
		*The variable p_bussnc has been generated from restricted data				

		*(Please Answer the Following Four Questions) in the space below:
		*Why do you want to be an Entrepreneur?
		*How did you get your business Idea?
		*Where do you Intend to locate your Business and Why?
		*Why will you succeed ?
			
		*Length of the question (note: max is 244)
		*Missing answers have obviously zero lenght
		*p_tlen has been generated from restricted data
		*Lenght first answer
		*p_tlen1 has been generated from restricted data
			
		*whether they answer in capital letters
		*p_tuppcas has been generated from restricted data
		*whether they say they want to be an “employer of labour” or “employer of labor”
		*p_templ has been generated from restricted data
			
		*whether they say “no competition” in answering f5
		*p_tcomp has been generated from restricted data
		
		*variables w/o missing
		gen su_bussn = p_bussn
		gen su_bussnb = p_bussnb
	
		*impute missings
		*codebook p_bussn p_bussnb p_bussnc p_tcomp p_templ p_tuppcas
		*never missing

	************************
	* Predictors from business plan
	************************
			
		*Total mark given in first round scoring
		*Note: no missings
		gen b_totmarkf = totalmark
			
		*Selected in first round
		*Note: no missings
		*gen b_round1 = passfirstround 
		*all 1 since we have dropped RD sample with no business scores
			
		*Total Business Plan score	
		gen b_totmark = totalmarks
		*Business plan score: component ability to manage
		gen b_maskill = ability_to_manage
		*Business plan score: component articulation
		gen b_artic = articulation 
		*Business plan score: component capstone
		gen b_cap = capstone 
		* Business plan score: component financial sources
		gen b_finsour = financial_sources
		*Business plan score: component financial sustainability
		gen b_finsust = financial_sustainability 
		*Business plan score: component financial viability
		gen b_finviab = financial_viability 
		*Business plan score: component job creation
		gen b_jobcreate = impact_job_creation 
		*Business plan score: component risk assessment
		gen b_risk = risk_assessment 
		*Business plan score: component time to market
		gen b_time = time_to_market
		*Business plan score: component understanding
		gen b_unders = understanding
			
		*Final national merit winners
		*Missing for the RD sample, count them as zero
		gen b_nmwin = (final_national_merit_winner==1)
		*Final zonal merit winners
		gen b_zmwin = (final_zonal_merit_winner==1) 
		*Final ordinary random winners
		gen b_owin = (final_ordinary_winner==1) 
		*Disqualified
		*gen b_disq = (disqualified==1) 
			
		*YouWin: Total award actually paid (in log)
		gen b_totaw = log(fa_totalawardpaid)
		gen b_totaw_m = missing(b_totaw)
		replace b_totaw = 0 if missing(b_totaw)
														
************************
* Checks
************************

	
	*drop variables collinear with existing, this is totally redundant
	*check any other remaining
	unab individualpredictors: p_*
	unab businessplan: b_*
	global PRED0 	`individualpredictors' `businessplan' 
	count
	local Ncheck = r(N)
	foreach var of global PRED0 {
		qui count if existing==`var' 
		if r(N)==`Ncheck' {
			di "`var'"
			_exit
		}
	}				
	
	*count number of predictors
	unab individualpredictors: p_*
	unab businessplan: b_*
	global PREDICTOR 	`individualpredictors' `businessplan' existing
	unab countvars : $PREDICTOR
	di `: word count `countvars''
	*559	

	*check that no variable is always zero
	foreach var of global PREDICTOR {
			qui sum `var' 
			if r(mean)==0 & r(sd)==0 {
				di "`var'"
				sum `var'
				_exit
			}	
	}
		
	*check that no variable is always one
	foreach var of global PREDICTOR {
			qui sum `var' 
			if r(mean)==1 & r(sd)==0 {
				di "`var'"
				sum `var'
				_exit
			}	
	}

	*check all have same number of obs as depvar
	count
	local Ncheck = r(N)
	foreach var of global PREDICTOR {
		qui sum `var' 
		if r(N)!=`Ncheck' {
			di "`var'"
			sum `var
			_exit
		}
	}				
		
	sum p_*
	sum b_*
	sum su_*
	sum o_*
	*
	*a few firms (34) have missing sales even if they are operating, this explains the difference in the number of observations
	*codebook t_bf5 if o_t_operatefirm==1

	*check that no obervations were lost in the process
	count
	*2492 (+624 RD dropped + 9 control with aid +14 disqualified= 3139)

************************
* Save final dataset
************************
	
	save "MLNigeria_masterdata.dta", replace
	
