**********************************
**********************************
** ML Nigeria
** A2 - Descriptive statistics
**********************************

/*
	READ ME
	Turn on/off: 
		set directory line 21
		then run the desired specification
*/


capture log close
clear all
set more off
version 14.2 

*set directory
cd 
*load data
use "Data\MLNigeria_masterdata.dta", clear

*Note:
*Firms in control group who actually recived award (9 firms) dropped during data cleaning (dofile A1)
*Firms without business plan scores from RD sample dropped during data cleaning (dofile A1)
*Firms disqualified dropped during data cleaning (dofile A1)

*set scheme graphs
*set scheme economist
*set scheme sj
set scheme s1mono
	
exit		
		
************************
* Descriptive statistics
************************

	***********
	*Survival rate (discussed in paper)
	***********

		*non-winners
		sum o_t_operatefirm if group==2|group==4
		*winners
		sum o_t_operatefirm if group==1|group==3
	
	***********
	*Figure 1: Substantial Dispersion in Firm Outcomes Three Years After Applying
	***********
			
		* Employment
		count if o_t_totalemp1>60 & o_t_totalemp1!=.
		graph twoway ///
				|| (kdensity o_t_totalemp1 if (group==1|group==3) & o_t_totalemp1>0 & o_t_totalemp1<=60, lw(medthick) lp(solid) lc(black)) ///
				|| (kdensity o_t_totalemp1 if (group==2|group==4) & o_t_totalemp1>0 & o_t_totalemp1<=60, lw(medthick) lp(dash) lc(black)) ///
				,  	title("Total Employment") ///
					legend(label(1 "Winners") label(2 "Non-winners"))  ///
					xtitle("Total Employment in Operating Firms") ytitle("Density") ///
					saving("Output/Fig1a.gph", replace)
		
		* Sales
		graph twoway ///
			|| (kdensity o_t_sales_IHS if (group==1|group==3) & o_t_sales>0, lw(medthick) lp(solid) lc(black)) ///
			|| (kdensity o_t_sales_IHS if (group==2|group==4) & o_t_sales>0, lw(medthick) lp(dash) lc(black)) ///
			,  	title("Sales") ///
				legend(label(1 "Winners") label(2 "Non-winners")) ///
				xtitle("Sales (IHS transformation)") ytitle("Density") ///
				saving("Output/Fig1b.gph", replace)
		
		* Profits
		graph twoway ///
			|| (kdensity o_t_profits_IHS if (group==1|group==3) & o_t_profits>0, lw(medthick) lp(solid) lc(black)) ///
			|| (kdensity o_t_profits_IHS if (group==2|group==4) & o_t_profits>0, lw(medthick) lp(dash) lc(black)) ///
			,  	title("Profits") ///
				legend(label(1 "Winners") label(2 "Non-winners")) ///
				xtitle("Profits (IHS transformation)") ytitle("Density") ///
				saving("Output/Fig1c.gph", replace)
					
		* combine into one figure for paper
		graph combine "Output/Fig1a.gph" "Output/Fig1b.gph" "Output/Fig1c.gph", ///
				col(2)  ///
				saving("Output/Figure1paper.gph", replace)
		
		* summary stats in paper
		sum o_t_profits if (group==1|group==3) & o_t_operatefirm==1, de
		sum o_t_totalemp1 if (group==1|group==3) & o_t_totalemp1>0, de
		
	***********
	*Figure 2: Distribution of Business Plan Scores by Competition Status
	***********

		graph twoway ///
			|| (kdensity totalmarks if group==3, lw(medthick) lp(solid) lc(black)) ///
			|| (kdensity totalmarks if group==1, lw(medthick) lp(longdash) lc(black)) ///
			|| (kdensity totalmarks if group==2, lw(medthick) lp(shortdash) lc(black)) ///
			|| (kdensity totalmarks if group==4, lw(medthick) lp(dash_dot) lc(black)) ///
			,  legend(label(1 "Non-Experimental Winner") label(2 "Experimental Winner") label(3 "Control Non-Winner") label(4 "Other Non-Winners") ) ///
				xtitle("Business plan score") ytitle("Density") ///
				saving("Output/Figure2.gph", replace)
		
		* Descriptive stats on marks
		sum totalmarks if group==1|group==3, de
		sum totalmarks if group==2|group==4, de

	***********
	*Figure 3: The Relationship between Business Plan Scores of Judges and Business Outcomes Three Years after applying 
	*for Non-Winners in the Business Plan Competition
	***********

		*Figure 3a: bar chart operating firm by quintile business plan score
		xtile markquintile=totalmarks if group==2|group==4, nq(5)
		egen meanoperate=mean(o_t_operatefirm) if group==2|group==4, by(markquintile)
		graph bar meanoperate if (group==2|group==4), ///
			over(markquintile) b1title("Business Plan Score Quintile") ///
			bar(1, color(black)) ///
			ytitle("Proportion operating a firm") saving("Output/Figure3apaper.gph", replace)
		
		*Figure 3b: sales conditional on operating
 		lowess o_t_sales_IHS totalmarks if (group==2|group==4) & o_t_operatefirm==1, yaxis(1) yscale(axis(1)) generate(ysales1)
		label var ysales1 "Conditional Lowess"
		lowess o_t_sales_IHS totalmarks if (group==2|group==4), yaxis(1) yscale(axis(1)) generate(ysales2)
		label var ysales2 "Unconditional Lowess"
		sort totalmarks
		graph twoway ///
			|| (scatter o_t_sales_IHS totalmarks if (group==2|group==4)) ///
			|| (line ysales1 totalmarks if (group==2|group==4), lw(medthick) lp(solid) lc(black)) ///
			|| (line ysales2 totalmarks if (group==2|group==4), lw(medthick) lp(dash) lc(black)), ///
			ytitle("IHS transformation of sales") xtitle("Business plan score") legend(off) saving("Output/Figure3bpaper.gph", replace)
		
		* Figure 3c: profits conditional on operating
		lowess o_t_profits_IHS totalmarks if (group==2|group==4) & o_t_operatefirm==1, yaxis(1) yscale(axis(1)) generate(yprof1)
		label var yprof1 "Conditional Lowess"
		lowess o_t_profits_IHS totalmarks if (group==2|group==4), yaxis(1) yscale(axis(1)) generate(yprof2)
		label var yprof2 "Unconditional Lowess"
		sort totalmarks
		graph twoway ///
			|| (scatter o_t_profits_IHS totalmarks if (group==2|group==4)) ///
			|| (line yprof1 totalmarks if (group==2|group==4), lw(medthick) lp(solid) lc(black)) ///
			|| (line yprof2 totalmarks if (group==2|group==4), lw(medthick) lp(dash) lc(black)), ///
			ytitle("IHS transformation of profits") xtitle("Business plan score") legend(off) saving("Output/Figure3cpaper.gph", replace)
		
		* Figure 3d: employment conditional on operating
		lowess o_t_totalemp1 totalmarks if (group==2|group==4) & o_t_operatefirm==1 & o_t_totalemp1<=60, yaxis(1) yscale(axis(1)) generate(yemp1)
		label var yemp1 "Conditional Lowess"
		lowess o_t_totalemp1 totalmarks if (group==2|group==4) & o_t_totalemp1<=60, yaxis(1) yscale(axis(1)) generate(yemp2)
		label var yemp2 "Unconditional Lowess"
		sort totalmarks
		graph twoway ///
			|| (scatter o_t_totalemp1 totalmarks if (group==2|group==4) & o_t_totalemp1<=60) ///
			|| (line yemp1 totalmarks if (group==2|group==4) & o_t_totalemp1<=60, lw(medthick) lp(solid) lc(black)) ///
			|| (line yemp2 totalmarks if (group==2|group==4) & o_t_totalemp1<=60, lw(medthick) lp(dash) lc(black)), /// 
			ytitle("Total Employment") xtitle("Business plan score") legend(off) saving("Output/Figure3dpaper.gph", replace)
		
		graph combine "Output\Figure3apaper.gph"  "Output\Figure3bpaper.gph" "Output\Figure3cpaper.gph" "Output\Figure3dpaper.gph", ///
			col(2) saving("Output/Figure3paper.gph", replace)

	***********
	*Figure 4: The Relationship between Business Plan Scores of Judges and Business Outcomes Three Years after applying 
	*for Winners in the Business Plan Competition
	***********
	
		*Figure 4a: bar chart operating firm by quintile business plan score
		xtile markquintile1=totalmarks if group==1|group==3, nq(5)
		egen meanoperate1=mean(o_t_operatefirm) if group==1|group==3, by(markquintile1)
		graph bar meanoperate1 if (group==1|group==3), ///
			over(markquintile1) b1title("Business Plan Score Quintile") ///
			bar(1, color(black)) ///
			ytitle("Proportion operating a firm") saving("Output/Figure4apaper.gph", replace)
		
		cap drop ysales1 ysales2 yprof1 yprof2 yemp1 yemp2
		* Figure 4b: sales conditional on operating
 		lowess o_t_sales_IHS totalmarks if (group==1|group==3) & o_t_operatefirm==1, yaxis(1) yscale(axis(1)) generate(ysales1)
		label var ysales1 "Conditional Lowess"
		lowess o_t_sales_IHS totalmarks if (group==1|group==3), yaxis(1) yscale(axis(1)) generate(ysales2)
		label var ysales2 "Unconditional Lowess"
		sort totalmarks
		graph twoway ///
			|| (scatter o_t_sales_IHS totalmarks if (group==1|group==3)) ///
			|| (line ysales1 totalmarks if (group==1|group==3), lw(medthick) lp(solid) lc(black)) ///
			|| (line ysales2 totalmarks if (group==1|group==3), lw(medthick) lp(dash) lc(black)), ///
			ytitle("IHS transformation of sales") xtitle("Business plan score") legend(off) saving("Output/Figure4bpaper.gph", replace)
		
		* Figure 4c: profits conditional on operating
		lowess o_t_profits_IHS totalmarks if (group==1|group==3) & o_t_operatefirm==1 & o_t_profits_IHS>=0, yaxis(1) yscale(axis(1)) generate(yprof1)
		label var yprof1 "Conditional Lowess"
		lowess o_t_profits_IHS totalmarks if (group==1|group==3) & o_t_profits_IHS>=0, yaxis(1) yscale(axis(1)) generate(yprof2)
		label var yprof2 "Unconditional Lowess"
		sort totalmarks
		graph twoway ///
			|| (scatter o_t_profits_IHS totalmarks if (group==1|group==3) & o_t_profits_IHS>=0) ///
			|| (line yprof1 totalmarks if (group==1|group==3) & o_t_profits_IHS>=0, lw(medthick) lp(solid) lc(black)) ///
			|| (line yprof2 totalmarks if (group==1|group==3) & o_t_profits_IHS>=0, lw(medthick) lp(dash) lc(black)), ///
			ytitle("IHS transformation of profits") xtitle("Business plan score") legend(off) saving("Output/Figure4cpaper.gph", replace)
		
		* Figure 4d: employment conditional on operating
		lowess o_t_totalemp1 totalmarks if (group==1|group==3) & o_t_operatefirm==1 & o_t_totalemp1<=60, yaxis(1) yscale(axis(1)) generate(yemp1)
		label var yemp1 "Conditional Lowess"
		lowess o_t_totalemp1 totalmarks if (group==1|group==3) & o_t_totalemp1<=60, yaxis(1) yscale(axis(1)) generate(yemp2)
		label var yemp2 "Unconditional Lowess"
		sort totalmarks
		graph twoway ///
			|| (scatter o_t_totalemp1 totalmarks if (group==1|group==3) & o_t_totalemp1<=60) ///
			|| (line yemp1 totalmarks if (group==1|group==3) & o_t_totalemp1<=60, lw(medthick) lp(solid) lc(black)) ///
			|| (line yemp2 totalmarks if (group==1|group==3) & o_t_totalemp1<=60, lw(medthick) lp(dash) lc(black)), /// 
			ytitle("Total Employment") xtitle("Business plan score") legend(off) saving("Output/Figure4dpaper.gph", replace)
		
		graph combine "Output\Figure4apaper.gph"  "Output\Figure4bpaper.gph" "Output\Figure4cpaper.gph" "Output\Figure4dpaper.gph", ///
			col(2) saving("Output/Figure4paper.gph", replace)

exit
