**********************************
**********************************
** ML Nigeria
** A2b - Added value ML predictors
**********************************
**********************************

/*
	READ ME
	Turn on/off: set directory line 23
		groups: lines 45-48
		controls: lines 72
		graph: 185-187
*/

capture log close
clear all
set more off
version 14.2 
set matsize 11000

*set directory
cd 
*load data
use "Data\MLNigeria_masterdata.dta", clear

*Note:
*Firms in control group who actually recived award (9 firms) dropped during data cleaning (dofile A1)
*Firms without business plan scores from RD sample dropped during data cleaning (dofile A1)
*Firms disqualified dropped during data cleaning (dofile A1)

*set scheme graphs
*set scheme economist
*set scheme sj
set scheme s1mono
			
************************
* Data Preparation
************************

	**************************************
	*Keep only relevant groups
	**************************************

		*winners
		keep if (group==1|group==3)
		*non-winners
		*keep if (group==2|group==4)

	**************************************
	*Drop predictors that are always zero
	**************************************
	
		unab pred0: p_*
		global PRED0	`pred0'
		
		foreach var of global PRED0 {
			qui sum `var' 
			if r(mean)==0 & r(sd)==0 {
				di "`var'"
				drop `var'
			}	
		}

		*FOR GROUP 1 AND 3. NOTE: FOR THE MAIN TABLE, DO NOT INCLUDE BUSINESS SCORES IN THE INPUTS
		*drop b_round1 since it is always one (all winners passed the first round)
		*drop b_round1. Not necessary since not generated in new version data. 
		*all 1 since we have dropped RD sample with no business scores
		
		*FOR GROUP 2 AND 4
		*drop also missing variable indicators related to these variables (only for bussiness name, the others were created from tab, gen so they are fine)
		*drop p_bussn_m p_bussnb_m p_bussnc_m p_mask_m p_mgive_m 
		*drop b_totaw_m
		
	**************************************
	*Global
	**************************************
	
		unab individualpredictors: p_*
		global PREDICTOR 	`individualpredictors' existing

		global MCKENZIE 	p_higheduc p_educ_m ///
							p_workabroad /*p_workabroad_m never missing*/ ///
							p_lot901 /*p_lot905 never missing*/ ///
							p_wealthindex /*p_wealthindex_m never missing*/ ///
							p_grit p_grit_m ///
							p_ability p_ability_m ///
							p_sector31 /*agriculture*/ p_sector19 /*IT*/
		
		global FAFCHAMPS	p_selfconfw1 p_selfconfw1_m ///
							p_motivation /*p_motivation_m never missing*/ ///
							p_satisf p_satisf_m ///
							p_satexp  p_satexp_m ///
							p_abilityfw p_abilityfw_m ///
							p_creditfw p_creditfw_m ///
							p_retail 
							
		global REGION		p_region1 p_region2 p_region3 p_region4 p_region5
		global DEMOG		p_female ///
							p_age /*p_age_m never missing*/
		global COMMON		$REGION $DEMOG ///
							p_manuf p_sector1 /*missing sector*/						

	**************************************
	*Keep only relevant variables
	**************************************		
		
		keep uid group $PREDICTOR /*o_* b_* b_totaw b_totaw_m*/
		qui compress
		*count predictors
		unab countvars : $PREDICTOR
		di `: word count `countvars''
		
exit		
							
************************
* Regressions
************************

	*generate variable with one line for predictor, just to keep track and double-check r2
	gen str1 predictors= ""
	local nxx : word count $PREDICTOR
	forvalues ii = 1/`nxx' { 
		local temp1 : word `ii' of $PREDICTOR
		label var `temp1' `temp1'
		local lab: variable label `temp1'
		replace predictors = "`lab'" in `ii'
	} 
	count if predictor!=""
	local npred = r(N)

	*regress each ML input on FaWo
	gen r2_fawo = .
	local i = 1
	foreach var of global PREDICTOR {
			qui sum `var' 
			if r(min)==0 & r(max)==1 {
				capture qui probit `var' $COMMON $FAFCHAMPS existing, iterate(500)
				qui replace r2_fawo = e(r2_p) in `i'
			}	
			else {
				capture qui regress `var' $COMMON $FAFCHAMPS existing
				qui replace r2_fawo = e(r2) in `i'
			}
			local i = `i' + 1
	}
	
	*regress each ML input on McKenzie
	gen r2_mk = .
	local i = 1
	foreach var of global PREDICTOR {
			qui sum `var' 
			if r(min)==0 & r(max)==1 {
				capture qui probit `var' $COMMON $MCKENZIE existing, iterate(500)
				qui replace r2_mk = e(r2_p) in `i'
			}	
			else {
				capture qui regress `var' $COMMON $MCKENZIE existing
				qui replace r2_mk = e(r2) in `i'
			}
			local i = `i' + 1
	}
	
	codebook r2_fawo r2_mk in 1/`npred'
	sum r2_fawo r2_mk in 1/`npred', d
	
	*those with missing values are perfectly collinear, put them as ones
	replace r2_fawo = 1 in 1/`npred' if r2_fawo==.
	replace r2_mk = 1 in 1/`npred' if r2_mk==.
	count if r2_fawo==1 in 1/`npred'
	count if r2_mk==1 in 1/`npred'
	
	*density
	graph twoway ///
		|| (kdensity r2_fawo, lw(medthick) lp(solid) lc(black)) ///
		|| (kdensity r2_mk, lw(medthick) lp(dash) lc(black)) ///
		,  	/*title("Non-winners")*/ title("Winners") ///
			legend(label(1 "FaWo") label(2 "McKenzie")) ///
			xtitle("R2") ytitle("Density") ///
			saving("Output/FigA1b.gph", replace) /*saving("Output/FigA1a.gph", replace)*/
	
exit

		* combine into one figure for paper
		graph combine "Output/FigA1a.gph" "Output/FigA1b.gph", ///
				col(2) ///
				saving("Output/FigureA1.gph", replace)

exit

************************
* Canonical analysis
************************

		*set of variables from econ models
		global econmod $COMMON $FAFCHAMPS $MCKENZIE existing
		
		
		*drop common variables between the two lists
		preserve
			*drop same variables
			drop $econmod
			*drop variables in PREDICTOR which are perfectly collinear with at least one variable in econmod
			drop p_region6 p_sector12 p_sector13 p_sector14 p_sector15 ///
				p_maconf3 p_maconf4 p_maconf5 p_mbconf2 p_mbconf3 p_mbconf4 p_mcconf2 ///
				p_mcconf3 p_mcconf4 p_mcconf5 p_mdconf2 p_mdconf3 p_mdconf4 p_mdconf5 p_meconf1 p_meconf2 p_meconf3 ///
				p_meconf4 p_mfconf1 p_mfconf2 p_mfconf3 p_mfconf4 p_mgconf1 p_mgconf2 p_mgconf3 p_mgconf4 p_mgconf5 ///
				p_mhconf1 p_mhconf2 p_mhconf3 p_mhconf4 p_miconf1 p_miconf2 p_miconf3 p_miconf4 ///
				p_satisfd11 p_satexpd10 p_maconf6 p_mbconf6 p_mcconf6 p_mdconf6 p_meconf6 p_mfconf6 p_mgconf6 p_mhconf6 p_miconf6 ///
				p_satexpd3 p_satexpd4 p_satexpd5 p_satexpd6 p_satexpd7 p_satexpd8 p_satexpd9 ///
				p_satisfd1 p_satisfd2 p_satisfd3 p_satisfd4 p_satisfd5 p_satisfd6 p_satisfd7 p_satisfd8 p_satisfd9 p_satisfd10 ///
				p_care1 p_care2 p_care3 p_care4 p_free1 p_free2 p_free3 p_free4 p_flex1 ///
				p_flex2 p_flex4 p_flex6 p_moremon1 p_moremon2 p_moremon3 p_moremon4 p_moremon5 p_needjob1 ///
				p_needjob4 p_needjob5 p_needjob6 p_growth1 p_growth2 p_growth3 p_excited1 p_excited2 p_excited3 ///
				p_excited4 p_excited6 p_needjob ///
				p_lbank p_lmicro p_lcoop p_mbconf5 p_miconf5 p_lmicro_m p_lcoop_m ///
				p_sector2 p_sector3 p_sector5 p_raven_m p_rava9 p_rava1 p_rava2 p_rava3 p_rava4 p_rava5 p_rava6 p_rava7 p_rava8 ///
				p_lot902 p_lot903 p_lot904 p_griti1 p_griti2 p_griti3 p_griti4 p_griti5 p_gritm1 p_gritm2 p_gritm3 p_gritm4 p_gritm5 ///
				p_sewing p_gascook p_estove p_gstove p_kstove p_fridge p_freezer p_ac p_gritn1 p_gritn2 p_gritn3 p_gritn4 p_gritn5 ///
				p_washmach p_dryer p_bike p_motorbike p_car p_generator p_hifi p_microwave p_tv p_computer p_dvd p_satellite ///
				p_4digit p_5digit p_6digit p_7digit p_8digit p_9digit p_10digit p_11digit p_digitspan ///
				p_gritg1 p_gritg2 p_gritg3 p_gritg4 p_gritg5 p_gritd1 p_gritd2 p_gritd3 p_gritd4 p_gritd5 p_grita1 p_grita2 p_grita3 p_grita4 p_grita5 ///
				p_gritc1 p_gritc2 p_gritc3 p_gritc4 p_gritc5 p_gritf1 p_gritf2 p_gritf3 p_gritf4 p_gritf5 p_gritb1 p_gritb2 p_gritb3 p_gritb4 p_gritb5 ///
				p_grite1 p_grite2 p_grite3 p_grite4 p_grite5 p_grith1 p_grith2 p_grith3 p_grith4 p_grith5 p_digitspan_m p_4digit_m ///
				p_gritl1 p_gritl2 p_gritl3 p_gritl4 p_gritl5 p_grita6 p_sector* p_rav*
			unab individualpredictors: p_*
			global PREDICTOR 	`individualpredictors' 
		restore
		unab countvars : $PREDICTOR
		di `: word count `countvars''
		unab countvars : $econmod
		di `: word count `countvars''
		

		*drop perfectly collinear variables
		_rmcoll $PREDICTOR, forcedrop
		*count predictors
		di r(varlist)
		global PREDICTOR `r(varlist)'
		unab countvars : $PREDICTOR
		di `: word count `countvars''
		
/*		
		*drop perfectly collinear variables between the two set of variables
		foreach var of global econmod {
				_rmdcoll `var' $PREDICTOR 
			}
*/	

		*there are some issues with p_satisf_m and p_satexp_m, drop them
		global FAFCHAMPS	p_selfconfw1 p_selfconfw1_m ///
							p_motivation /*p_motivation_m never missing*/ ///
							p_satisf ///
							p_satexp ///
							p_abilityfw p_abilityfw_m ///
							p_creditfw p_creditfw_m ///
							p_retail 
							
		canon ($COMMON $FAFCHAMPS existing) ($PREDICTOR)
		*canon ($COMMON $MCKENZIE existing) ($PREDICTOR)
		canon, test(1(1)21)

