**********************************
**********************************
** ML Nigeria
** A3 - Business plan vs. Survey
**********************************
**********************************

/*
	READ ME
	Turn on/off: 
		set directory line 21
		then run the desired specification
*/

capture log close
clear all
set more off
version 14.1 

*set directory
cd 
*load data
use "Data\MLNigeria_masterdata.dta", clear

*Note:
*Firms in control group who actually recived award (9 firms) dropped during data cleaning (dofile A1)
*Firms without business plan scores from RD sample dropped during data cleaning (dofile A1)
*Firms disqualified dropped during data cleaning (dofile A1)

**************************************
*Global
**************************************

	global MCKENZIE 	p_higheduc p_educ_m ///
						p_workabroad /*p_workabroad_m never missing*/ ///
						p_lot901 /*p_lot905 never missing*/ ///
						p_wealthindex /*p_wealthindex_m never missing*/ ///
						p_grit p_grit_m ///
						p_ability p_ability_m ///
						p_sector31 /*agriculture*/ p_sector19 /*IT*/
						
	global FAFCHAMPS	p_selfconfw1 p_selfconfw1_m ///
						p_motivation /*p_motivation_m never missing*/ ///
						p_satisf p_satisf_m ///
						p_satexp  p_satexp_m ///
						p_abilityfw p_abilityfw_m ///
						p_creditfw p_creditfw_m ///
						p_retail 
						
	global REGION		p_region1 p_region2 p_region3 p_region4 p_region5
	global DEMOG		p_female ///
						p_age /*p_age_m never missing*/
	global COMMON		$REGION $DEMOG ///
						p_manuf p_sector1 /*missing sector*/
						
	sum $MCKENZIE $FAFCHAMPS $COMMON
	
exit

********************************	
***** Table 1: Survival 
********************************

	eststo clear

	********************************	
	* Accuracy
	********************************
	
		capture program drop paccuracy
		program paccuracy
		
			*set threshold probability 
			local pbar = 0.5
			*predict probability of outcome variable
			predict probyhat
			*predict yhat 0/1
			qui gen yhat = 1 if probyhat>=`pbar' & !missing(probyhat)
			qui replace yhat = 0 if probyhat<`pbar' & !missing(probyhat)				
			*compute % correct predictions (accuracy)
			qui generate accuracy = (o_t_operatefirm == yhat) if !missing(yhat)
			tab o_t_operatefirm yhat if e(sample), row
			sum accuracy if e(sample)
			*drop variables
			drop probyhat yhat accuracy
					 
		end		
	
	********************************	
	* Non-winners
	********************************
	
		* Column 1: Judges Scores for Non-Winners
		logit o_t_operatefirm b_totmark existing if (group==2|group==4), robust
			paccuracy
		margins, dydx(*) post
		eststo surv1, title(Judges)		
					
		* Column 2: McKenzie (2015) prediction model				
		logit o_t_operatefirm b_totmark $COMMON $MCKENZIE existing if (group==2|group==4), robust
			paccuracy
		margins, dydx(*) post
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo surv2, title(McKenzie)	
								
		* Column 3: Fafchamps and Woodruff (2016) prediction model
		logit o_t_operatefirm b_totmark $COMMON $FAFCHAMPS existing  if (group==2|group==4), robust
			paccuracy
		margins, dydx(*) post
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo surv3, title(FaWo)	
								
	********************************	
	* Winners
	********************************
		
		* Column 4: Judges Scores for Winners
		logit o_t_operatefirm b_totmark existing  if (group==1|group==3), robust
			paccuracy
		margins, dydx(*) post
		eststo surv4, title(Judges)	
					
		* Column 5: Judges Scores for Winners, controlling for amount awarded
		logit o_t_operatefirm b_totmark existing b_totaw b_totaw_m if (group==1|group==3), robust
			paccuracy
		margins, dydx(*) post
		eststo surv5, title(Judges)	
					
		* Column 6: McKenzie (2015) prediction model				
		logit o_t_operatefirm b_totmark $COMMON $MCKENZIE existing b_totaw b_totaw_m  if (group==1|group==3), robust
			paccuracy
		margins, dydx(*) post
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo surv6, title(McKenzie)	
				
		* Column 7: Fafchamps and Woodruff (2016) prediction model
		logit o_t_operatefirm b_totmark $COMMON $FAFCHAMPS existing b_totaw b_totaw_m  if (group==1|group==3), robust
			paccuracy
		margins, dydx(*) post
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo surv7, title(FaWo)
				
	********************************	
	* Table
	********************************
	
		esttab surv1 surv2 surv3 surv4 surv5 surv6 surv7 ///
			using "Output/Table1Survival.rtf", replace ///
			se(%5.4f) b(%5.4f) ///
			order(	b_totmark p_female p_age p_higheduc p_workabroad p_lot901 p_wealthindex p_grit ///
					p_sector31 p_sector19 p_ability p_abilityfw p_manuf p_retail ///
					p_selfconfw1 p_motivation p_satisf p_satexp p_creditfw ///
					existing b_totaw ///
					) ///
			drop(p_educ_m b_totaw_m p_grit_m p_sector1 p_ability_m p_satisf_m p_satexp_m p_abilityfw_m p_creditfw_m p_selfconfw1_m)  ///
			varlabels( _cons Constant ///
						b_totmark		"Business Plan score" ///
						existing		"Existing" ///
						b_totaw   		"Log(Total award paid)" ///
						p_female 		"Female" ///
						p_age			"Age" ///
						p_higheduc 		"Graduate Education" ///
						p_workabroad 	"Worked abroad" ///
						p_lot901		"Lottery choice" ///
						p_wealthindex	"Wealth" ///
						p_grit			"Grit" ///
						p_ability		"Ability" /// 
						p_sector31 		"Agriculture" ///
						p_manuf 		"Manufacture" ///
						p_sector19		"IT" ///
						p_retail		"Retail" ///
						p_selfconfw1	"Self-confidence" ///
						p_motivation 	"Motivation" /// 
						p_satisf 		"Happiness" ///
						p_satexp 		"Optimism" ///
						p_abilityfw		"Ability" ///
						p_creditfw 		"Credit" ///
							) /// 
				stats(N pval1 accu1, labels("Sample Size" P-Value Accuracy) ///
								fmt(%6.0f %9.3f %9.3f)) ///
				mtitles style(tex) ///
				modelwidth(6) varwidth(19) ///
				title({\b Table 1: Can Human Experts Predict Business Survival After 3 Years?}) ///
				addnotes (	"Robust Standard Errors in parentheses. *, **, *** denote significance at the 10, 5, and 1 percent levels respectively" ///
							"See Appendix A.1 for variable definitions" ///
							"Dependent variable is having a business in operation 3 years after applying." ///
							"Marginal effects from logit shown." ///
							"P-value is for testing that set of controls added by MacKenzie (2015) or Fafchamps and Woodruff (2017) (abbreviated as FaWo) are jointly zero" ///
							) ///
				indicate("Regional Indicators = $REGION") ///
				star(* 0.10 ** 0.05 *** 0.01) ///
				label
	
***********************************				
***** Table 2: Employment 
***********************************

	eststo clear
	
	********************************	
	* Non-winners
	********************************

		* Column 1: Judges Scores for Non-Winners
		regress o_t_totalemp1 b_totmark existing  if (group==2|group==4), robust
		estadd scalar mse=e(rmse)^2
		eststo emp1, title(Judges)	
			
		* Column 2: McKenzie (2015) prediction model				
		regress o_t_totalemp1 b_totmark $COMMON $MCKENZIE existing  if (group==2|group==4), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo emp2, title(McKenzie)	
				
		* Column 3: Fafchamps and Woodruff (2016) prediction model
		regress o_t_totalemp1 b_totmark $COMMON $FAFCHAMPS existing  if (group==2|group==4), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo emp3, title(FaWo)
		
	********************************	
	* Winners
	********************************
	
		* Column 4: Judges Scores for Winners
		regress o_t_totalemp1 b_totmark existing  if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		eststo emp4, title(Judges)	
				
		* Column 5: Judges Scores for Winners, controlling for amount awarded
		regress o_t_totalemp1 b_totmark existing  b_totaw b_totaw_m if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		eststo emp5, title(Judges)	
			
		* Column 6: McKenzie (2015) prediction model				
		regress o_t_totalemp1 b_totmark $COMMON $MCKENZIE existing b_totaw b_totaw_m  if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo emp6, title(McKenzie)	
				
		* Column 7: Fafchamps and Woodruff (2016) prediction model
		regress o_t_totalemp1 b_totmark $COMMON $FAFCHAMPS existing b_totaw b_totaw_m  if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo emp7, title(FaWo)
				
	********************************	
	* Table
	********************************
	
		esttab emp1 emp2 emp3 emp4 emp5 emp6 emp7 ///
			using "Output/Table2Employment.rtf", replace ///
			se(%5.4f) b(%5.4f) ///
			order(	b_totmark p_female p_age p_higheduc p_workabroad p_lot901 p_wealthindex p_grit ///
					p_sector31 p_sector19 p_ability p_abilityfw p_manuf p_retail ///
					p_selfconfw1 p_motivation p_satisf p_satexp p_creditfw ///
					existing b_totaw ///
					) ///
			drop(p_educ_m b_totaw_m p_grit_m p_sector1 p_ability_m p_satisf_m p_satexp_m p_abilityfw_m p_creditfw_m p_selfconfw1_m)  ///
			varlabels( _cons Constant ///
						b_totmark		"Business Plan score" ///
						existing		"Existing" ///
						b_totaw   		"Log(Total award paid)" ///
						p_female 		"Female" ///
						p_age			"Age" ///
						p_higheduc 		"Graduate Education" ///
						p_workabroad 	"Worked abroad" ///
						p_lot901		"Lottery choice" ///
						p_wealthindex	"Wealth" ///
						p_grit			"Grit" ///
						p_ability		"Ability" /// 
						p_sector31 		"Agriculture" ///
						p_manuf 		"Manufacture" ///
						p_sector19		"IT" ///
						p_retail		"Retail" ///
						p_selfconfw1	"Self-confidence" ///
						p_motivation 	"Motivation" /// 
						p_satisf 		"Happiness" ///
						p_satexp 		"Optimism" ///
						p_abilityfw		"Ability" ///
						p_creditfw 		"Credit" ///
							) /// 
				stats(N pval1 r2_a mse, labels("Sample Size" "P-value" "Adjusted R2" "MSE") ///
								fmt(%6.0f %9.3f %9.3f %9.2f)) ///
				mtitles style(tex) ///
				modelwidth(6) varwidth(19) ///
				title({\b Table 2: Can Human Experts Predict Employment After 3 Years? }) ///
				addnotes (	"Robust Standard Errors in parentheses. *, **, *** denote significance at the 10, 5, and 1 percent levels respectively." ///
							"See Appendix A.1 for variable definitions." ///
							"Dependent variable is number of employees 3 years after applying, coded as zero for applicants without an operating firm." ///
							"P-value is for testing that set of controls added by MacKenzie (2015) or Fafchamps and Woodruff (2017) (abbreviated as FaWo) are jointly zero." ///
							) ///
				indicate("Regional Indicators = $REGION") ///
				star(* 0.10 ** 0.05 *** 0.01) ///
				label

*******************************			
**** Table 3: Profits 
*******************************

		eststo clear
		
	********************************	
	* Non-winners
	********************************
		
		* Column 1: Judges Scores for Non-Winners
		regress o_t_profits_IHS b_totmark existing  if (group==2|group==4), robust
		estadd scalar mse=e(rmse)^2
		eststo pro1, title(Judges)	
		
		* Column 2: McKenzie (2015) prediction model				
		regress o_t_profits_IHS b_totmark $COMMON $MCKENZIE existing  if (group==2|group==4), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo pro2, title(McKenzie)	
				
		* Column 3: Fafchamps and Woodruff (2016) prediction model
		regress o_t_profits_IHS b_totmark $COMMON $FAFCHAMPS existing  if (group==2|group==4), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo pro3, title(Fafchamps)	

	********************************	
	* Winners
	********************************
				
		* Column 4: Judges Scores for Winners
		regress o_t_profits_IHS b_totmark existing  if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		eststo pro4, title(Judges)	
				
		* Column 5: Judges Scores for Winners, controlling for amount awarded
		regress o_t_profits_IHS b_totmark existing  b_totaw b_totaw_m if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		eststo pro5, title(Judges)	

		* Column 6: McKenzie (2015) prediction model				
		regress o_t_profits_IHS b_totmark $COMMON $MCKENZIE existing b_totaw b_totaw_m  if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo pro6, title(McKenzie)	
				
		* Column 7: Fafchamps and Woodruff (2016) prediction model
		regress o_t_profits_IHS b_totmark $COMMON $FAFCHAMPS existing b_totaw b_totaw_m  if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo pro7, title(Fafchamps)
				
	********************************	
	* Table
	********************************

		esttab pro1 pro2 pro3 pro4 pro5 pro6 pro7 ///
			using "Output/Table3Profits.rtf", replace ///
			se(%5.4f) b(%5.4f) ///
			order(	b_totmark p_female p_age p_higheduc p_workabroad p_lot901 p_wealthindex p_grit ///
					p_sector31 p_sector19 p_ability p_abilityfw p_manuf p_retail ///
					p_selfconfw1 p_motivation p_satisf p_satexp p_creditfw ///
					existing b_totaw ///
					) ///
			drop(p_educ_m b_totaw_m p_grit_m p_sector1 p_ability_m p_satisf_m p_satexp_m p_abilityfw_m p_creditfw_m p_selfconfw1_m)  ///
			varlabels( _cons Constant ///
						b_totmark		"Business Plan score" ///
						existing		"Existing" ///
						b_totaw   		"Log(Total award paid)" ///
						p_female 		"Female" ///
						p_age			"Age" ///
						p_higheduc 		"Graduate Education" ///
						p_workabroad 	"Worked abroad" ///
						p_lot901		"Lottery choice" ///
						p_wealthindex	"Wealth" ///
						p_grit			"Grit" ///
						p_ability		"Ability" /// 
						p_sector31 		"Agriculture" ///
						p_manuf 		"Manufacture" ///
						p_sector19		"IT" ///
						p_retail		"Retail" ///
						p_selfconfw1	"Self-confidence" ///
						p_motivation 	"Motivation" /// 
						p_satisf 		"Happiness" ///
						p_satexp 		"Optimism" ///
						p_abilityfw		"Ability" ///
						p_creditfw 		"Credit" ///
							) /// 
				stats(N pval1 r2_a mse, labels("Sample Size" "P-value" "Adjusted R2" "MSE") ///
								fmt(%6.0f %9.3f %9.3f %9.2f)) ///
				mtitles style(tex) ///
				modelwidth(6) varwidth(19) ///
				title({\b Table 3: Can Human Experts Predict Profits After 3 Years? }) ///
				addnotes (	"Robust Standard Errors in parentheses. *, **, *** denote significance at the 10, 5, and 1 percent levels respectively." ///
							"See Appendix A.1 for variable definitions." ///
							"Dependent variable is inverse hyperbolic sine of profits 3 years after applying, coded as zero for applicants without an operating firm." ///
							"P-value is for testing that set of controls added by MacKenzie (2015) or Fafchamps and Woodruff (2017) (abbreviated as FaWo) are jointly zero." ///
							) ///
				indicate("Regional Indicators = $REGION") ///	
				star(* 0.10 ** 0.05 *** 0.01) ///
				label
				
*******************************
***** Table A1: Sales
*******************************

		eststo clear
		
	********************************	
	* Non-winners
	********************************
		
		* Column 1: Judges Scores for Non-Winners
		regress o_t_sales_IHS b_totmark existing  if (group==2|group==4), robust
		estadd scalar mse=e(rmse)^2
		eststo sale1, title(Judges)	

		* Column 2: McKenzie (2015) prediction model				
		regress o_t_sales_IHS b_totmark $COMMON $MCKENZIE existing  if (group==2|group==4), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo sale2, title(McKenzie)	
				
		* Column 3: Fafchamps and Woodruff (2016) prediction model
		regress o_t_sales_IHS b_totmark $COMMON $FAFCHAMPS existing  if (group==2|group==4), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo sale3, title(Fafchamps)	

	********************************	
	* Winners
	********************************
		
		* Column 4: Judges Scores for Winners
		regress o_t_sales_IHS b_totmark existing  if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		eststo sale4, title(Judges)	
				
		* Column 5: Judges Scores for Winners, controlling for amount awarded
		regress o_t_sales_IHS b_totmark existing  b_totaw b_totaw_m if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		eststo sale5, title(Judges)	
			
		* Column 6: McKenzie (2015) prediction model				
		regress o_t_sales_IHS b_totmark $COMMON $MCKENZIE existing b_totaw b_totaw_m  if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo sale6, title(McKenzie)	
				
		* Column 7: Fafchamps and Woodruff (2016) prediction model
		regress o_t_sales_IHS b_totmark $COMMON $FAFCHAMPS existing b_totaw b_totaw_m  if (group==1|group==3), robust
		estadd scalar mse=e(rmse)^2
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo sale7, title(Fafchamps)
				
	********************************	
	* Table
	********************************
	
		esttab sale1 sale2 sale3 sale4 sale5 sale6 sale7 ///
			using "Output/TableA1Sales.rtf", replace ///
			se(%5.4f) b(%5.4f) ///
			order(	b_totmark p_female p_age p_higheduc p_workabroad p_lot901 p_wealthindex p_grit ///
					p_sector31 p_sector19 p_ability p_abilityfw p_manuf p_retail ///
					p_selfconfw1 p_motivation p_satisf p_satexp p_creditfw ///
					existing b_totaw ///
					) ///
			drop(p_educ_m b_totaw_m p_grit_m p_sector1 p_ability_m p_satisf_m p_satexp_m p_abilityfw_m p_creditfw_m p_selfconfw1_m)  ///
			varlabels( _cons Constant ///
						b_totmark		"Business Plan score" ///
						existing		"Existing" ///
						b_totaw   		"Log(Total award paid)" ///
						p_female 		"Female" ///
						p_age			"Age" ///
						p_higheduc 		"Graduate Education" ///
						p_workabroad 	"Worked abroad" ///
						p_lot901		"Lottery choice" ///
						p_wealthindex	"Wealth" ///
						p_grit			"Grit" ///
						p_ability		"Ability" /// 
						p_sector31 		"Agriculture" ///
						p_manuf 		"Manufacture" ///
						p_sector19		"IT" ///
						p_retail		"Retail" ///
						p_selfconfw1	"Self-confidence" ///
						p_motivation 	"Motivation" /// 
						p_satisf 		"Happiness" ///
						p_satexp 		"Optimism" ///
						p_abilityfw		"Ability" ///
						p_creditfw 		"Credit" ///
							) /// 
				stats(N pval1 r2_a mse, labels("Sample Size" "P-value" "Adjusted R2" "MSE") ///
								fmt(%6.0f %9.3f %9.3f %9.2f)) ///
				mtitles style(tex) ///
				modelwidth(6) varwidth(19) ///
				title({\b Table A1: Can Human Experts Predict Sales After 3 Years? }) ///
				addnotes (	"Robust Standard Errors in parentheses. *, **, *** denote significance at the 10, 5, and 1 percent levels respectively." ///
							"See Appendix A.1 for variable definitions." ///
							"Dependent variable is inverse hyperbolic sine of sales 3 years after applying, coded as zero for applicants without an operating firm." ///
							"P-value is for testing that set of controls added by MacKenzie (2015) or Fafchamps and Woodruff (2017) (abbreviated as FaWo) are jointly zero." ///
							) ///
				indicate("Regional Indicators = $REGION") ///
				star(* 0.10 ** 0.05 *** 0.01) ///
				label	
				
****************************************************************************************************************************************************************	
****************************************************************************************************************************************************************	
****************************************************************************************************************************************************************	

**************************************************************************************************
**** Appendix Table A2: Does including Judge Fixed Effects Change Impact of Business Score ? *****
**************************************************************************************************

		eststo clear $REGION
	
	********************************	
	* Non-winners
	********************************
	
		* Survival 				
		logit o_t_operatefirm b_totmark existing  if (group==2|group==4), robust
		margins, dydx(*) post
		eststo A3a_1, title(Survival)					
		logit o_t_operatefirm b_totmark existing i.marker_id if (group==2|group==4), robust
		margins, dydx(*) post
		eststo A3b_1, title(Survival)			
		logit o_t_operatefirm b_totmark existing $REGION if (group==2|group==4), robust
		margins, dydx(*) post
		eststo A3c_1, title(Survival)			
		
		* Employment
		regress o_t_totalemp1 b_totmark existing  if (group==2|group==4), robust
		eststo A3a_2, title(Employment)	
		regress o_t_totalemp1 b_totmark existing i.marker_id if (group==2|group==4), robust
		eststo A3b_2, title(Employment)	
		regress o_t_totalemp1 b_totmark existing $REGION if (group==2|group==4), robust
		eststo A3c_2, title(Employment)	
				
		* Sales
		regress o_t_sales_IHS b_totmark existing  if (group==2|group==4), robust
		eststo A3a_3, title(Sales)	
		regress o_t_sales_IHS b_totmark existing i.marker_id if (group==2|group==4), robust
		eststo A3b_3, title(Sales)				
		regress o_t_sales_IHS b_totmark existing $REGION if (group==2|group==4), robust
		eststo A3c_3, title(Sales)	
				
		* Profits
		regress o_t_profits_IHS b_totmark existing  if (group==2|group==4), robust
		eststo A3a_4, title(Profits)	
		regress o_t_profits_IHS b_totmark existing i.marker_id if (group==2|group==4), robust
		eststo A3b_4, title(Profits)	
		regress o_t_profits_IHS b_totmark existing $REGION if (group==2|group==4), robust
		eststo A3c_4, title(Profits)	

	********************************	
	* Winners
	********************************

		* Survival 				
		logit o_t_operatefirm b_totmark existing  if (group==1|group==3), robust
		margins, dydx(*) post
		eststo A3a_5, title(Survival)					
		logit o_t_operatefirm b_totmark existing i.marker_id if (group==1|group==3), robust
		margins, dydx(*) post
		eststo A3b_5, title(Survival)			
		logit o_t_operatefirm b_totmark existing $REGION if (group==1|group==3), robust
		margins, dydx(*) post
		eststo A3c_5, title(Survival)					
		
		* Employment
		regress o_t_totalemp1 b_totmark existing  if (group==1|group==3), robust
		eststo A3a_6, title(Employment)	
		regress o_t_totalemp1 b_totmark existing i.marker_id if (group==1|group==3), robust
		eststo A3b_6, title(Employment)	
		regress o_t_totalemp1 b_totmark existing $REGION if (group==1|group==3), robust
		eststo A3c_6, title(Employment)	
				
		* Sales
		regress o_t_sales_IHS b_totmark existing  if (group==1|group==3), robust
		eststo A3a_7, title(Sales)	
		regress o_t_sales_IHS b_totmark existing i.marker_id if (group==1|group==3), robust
		eststo A3b_7, title(Sales)				
		regress o_t_sales_IHS b_totmark existing $REGION if (group==1|group==3), robust
		eststo A3c_7, title(Sales)	
				
		* Profits
		regress o_t_profits_IHS b_totmark existing  if (group==1|group==3), robust
		eststo A3a_8, title(Profits)	
		regress o_t_profits_IHS b_totmark existing i.marker_id if (group==1|group==3), robust
		eststo A3b_8, title(Profits)	
		regress o_t_profits_IHS b_totmark existing $REGION if (group==1|group==3), robust
		eststo A3c_8, title(Profits)	
			
	********************************	
	* Table
	********************************
			
		esttab A3a_* A3b_* A3c_*  ///
			using "Output/TableA2.rtf", replace ///
					se(%5.4f) b(%5.4f) ///
					order(b_totmark	existing) ///
					drop(*marker_id* $REGION) ///
					varlabels( _cons Constant ///
								b_totmark		"Business Plan score" ///
								existing		"Existing" ///
									) /// 
			stats(N  r2_a , labels("Sample Size" "Adjusted R2" ) ///
								fmt(%6.0f %9.3f)) ///
			mtitles style(tex) ///
			modelwidth(6) varwidth(19) ///
			title("Table A2: Robustness to Including Judge Fixed Effects") ///
			star(* 0.10 ** 0.05 *** 0.01) ///
			label

*************************************************************			
***** Appendix Table A3: do sub-scores do any better? 
*************************************************************
	
		eststo clear

	********************************	
	* Non-winners
	********************************
	
		global BSUBSCORES b_maskill b_artic b_cap b_finsour b_finsust b_finviab b_jobcreate b_risk b_time b_unders
	
		* Column 1: Survival for Non-Winners
		logit o_t_operatefirm $BSUBSCORES existing  if (group==2|group==4), robust
		margins, dydx(*) post
		test b_maskill==b_artic==b_cap==b_finsour==b_finsust==b_finviab==b_jobcreate==b_risk==b_time==b_unders==0
		estadd scalar pval1=r(p)
		eststo app1, title(Survival)		
		
		* Column 2: Employment for Non-Winners
		regress o_t_totalemp1 $BSUBSCORES existing  if (group==2|group==4), robust
		test b_maskill==b_artic==b_cap==b_finsour==b_finsust==b_finviab==b_jobcreate==b_risk==b_time==b_unders==0
		estadd scalar pval1=r(p)
		eststo app2, title(Employment)	
		
		* Column 3: Sales for Non-Winners
		regress o_t_sales_IHS $BSUBSCORES existing  if (group==2|group==4), robust
		test b_maskill==b_artic==b_cap==b_finsour==b_finsust==b_finviab==b_jobcreate==b_risk==b_time==b_unders==0
		estadd scalar pval1=r(p)
		eststo app3, title(Sales)	
		
		* Column 4: Profits for Non-Winners
		regress o_t_profits_IHS $BSUBSCORES existing  if (group==2|group==4), robust
		test b_maskill==b_artic==b_cap==b_finsour==b_finsust==b_finviab==b_jobcreate==b_risk==b_time==b_unders==0
		estadd scalar pval1=r(p)
		eststo app4, title(Profits)	

	********************************	
	* Winners
	********************************
		
		* Column 5: Survival for Winners
		logit o_t_operatefirm $BSUBSCORES existing b_totaw b_totaw_m if (group==1|group==3), robust
		margins, dydx(*) post
		test b_maskill==b_artic==b_cap==b_finsour==b_finsust==b_finviab==b_jobcreate==b_risk==b_time==b_unders==0
		estadd scalar pval1=r(p)
		eststo app5, title(Survival)		
		
		* Column 6: Employment for Winners
		regress o_t_totalemp1 $BSUBSCORES existing b_totaw b_totaw_m if (group==1|group==3), robust
		test b_maskill==b_artic==b_cap==b_finsour==b_finsust==b_finviab==b_jobcreate==b_risk==b_time==b_unders==0
		estadd scalar pval1=r(p)
		eststo app6, title(Employment)	
		
		* Column 7: Sales for Winners
		regress o_t_sales_IHS $BSUBSCORES existing b_totaw b_totaw_m if (group==1|group==3), robust
		test b_maskill==b_artic==b_cap==b_finsour==b_finsust==b_finviab==b_jobcreate==b_risk==b_time==b_unders==0
		estadd scalar pval1=r(p)
		eststo app7, title(Sales)	
		
		* Column 8: Profits for Winners
		regress o_t_profits_IHS $BSUBSCORES existing b_totaw b_totaw_m if (group==1|group==3), robust
		test b_maskill==b_artic==b_cap==b_finsour==b_finsust==b_finviab==b_jobcreate==b_risk==b_time==b_unders==0
		estadd scalar pval1=r(p)
		eststo app8, title(Profits)	
	
	********************************	
	* Table
	********************************

		esttab app1 app2 app3 app4 app5 app6 app7 app8 ///
			using "Output/TableA3.rtf", replace ///
			se(%4.3f) b(%4.3f) ///
			order($BSUBSCORES existing  b_totaw) ///
			drop(b_totaw_m )  ///
			varlabels( _cons Constant ///
						b_maskill 		"Score: ability to manage" ///
						b_artic 		"Score: articulation" ///
						b_cap 			"Score: capstone" ///
						b_finsour 		"Score: financial sources" ///
						b_finsust 		"Score: financial sustainability" ///
						b_finviab 		"Score: financial viability" ///
						b_jobcreate 	"Score: job creation" ///
						b_risk 			"Score: risk assessment" ///
						b_time 			"Score: time to market" ///
						b_unders		"Score: understanding" ///
						existing		"Existing" ///
						b_totaw		  	"Log(Tot award paid)" ///
							) /// 
				stats(N r2_a pval1, labels("Sample Size" AdjR^2 "p-value") ///
									fmt(%6.0f %4.3f  %9.3f)) ///
				mtitles style(tex) ///
				modelwidth(6) varwidth(19) ///
				title({\b Table A3: Do Sub-Scores of Judges Predict Outcomes}) ///
				addnotes (	"Robust Standard errors in parentheses. *, **, *** denote significance at the 10, 5, and 1 percent levels respectively." ///
							"P-value is for F-test that all ten sub-scores are jointly unrelated to the business outcome three years after application." ///
						  ) ///
				star(* 0.10 ** 0.05 *** 0.01) ///
				label
				
************************************************************************************
**** Appendix Table A4: Impacts conditional on firm operating for Non-winners 
************************************************************************************
	
		eststo clear
		
		* columns 1 to 3: Employment
		* Column 1: Judges Scores for Non-Winners
		regress o_t_totalemp1 b_totmark existing  if (group==2|group==4) & o_t_operatefirm==1, robust
		eststo emp1, title(Scores)	
			
		* Column 2: McKenzie (2015) prediction model				
		regress o_t_totalemp1 b_totmark $COMMON $MCKENZIE existing  if (group==2|group==4) & o_t_operatefirm==1, robust
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo emp2, title(McKenzie)	
				
		* Column 3: Fafchamps and Woodruff (2016) prediction model
		regress o_t_totalemp1 b_totmark $COMMON $FAFCHAMPS existing  if (group==2|group==4) & o_t_operatefirm==1, robust
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo emp3, title(Fafchamps)	
				
		* columns 4 to 6: Sales
		* Column 4: Judges Scores for Non-Winners
		regress o_t_sales_IHS b_totmark existing  if (group==2|group==4) & o_t_operatefirm==1, robust
		eststo sale1, title(Scores)	

		* Column 5: McKenzie (2015) prediction model				
		regress o_t_sales_IHS b_totmark $COMMON $MCKENZIE existing  if (group==2|group==4) & o_t_operatefirm==1, robust
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo sale2, title(McKenzie)	
				
		* Column 6: Fafchamps and Woodruff (2016) prediction model
		regress o_t_sales_IHS b_totmark $COMMON $FAFCHAMPS existing  if (group==2|group==4) & o_t_operatefirm==1, robust
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo sale3, title(Fafchamps)
				
		* columns 7 to 9: Profits
		* Column 7: Judges Scores for Non-Winners
		regress o_t_profits_IHS b_totmark existing  if (group==2|group==4) & o_t_operatefirm==1, robust
		eststo pro1, title(Scores)	
		
		* Column 8: McKenzie (2015) prediction model				
		regress o_t_profits_IHS b_totmark $COMMON $MCKENZIE existing  if (group==2|group==4) & o_t_operatefirm==1, robust
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_higheduc = p_educ_m = p_workabroad = p_lot901 = p_wealthindex = p_grit = p_grit_m = p_ability = ///
			 p_ability_m = p_sector31 = p_sector19 = 0
		estadd scalar pval1=r(p)
		eststo pro2, title(McKenzie)	
				
		* Column 9: Fafchamps and Woodruff (2016) prediction model
		regress o_t_profits_IHS b_totmark $COMMON $FAFCHAMPS existing  if (group==2|group==4) & o_t_operatefirm==1, robust
		test p_female = p_age = p_manuf = p_sector1 = ///
			 p_selfconfw1 = p_selfconfw1_m = p_motivation = p_satisf = p_satisf_m = p_satexp  = p_satexp_m = ///
			 p_abilityfw = p_abilityfw_m = p_creditfw = p_creditfw_m = p_retail = 0
		estadd scalar pval1=r(p)
		eststo pro3, title(Fafchamps)	

		*Table 
		esttab emp1 emp2 emp3 sale1 sale2 sale3 pro1 pro2 pro3  ///
			using "Output/TableA4.rtf", replace ///
			se(%5.4f) b(%5.4f) ///
			order(	b_totmark p_female p_age p_higheduc p_workabroad p_lot901 p_wealthindex p_grit ///
					p_sector31 p_sector19 p_ability p_abilityfw p_manuf p_retail ///
					p_selfconfw1 p_motivation p_satisf p_satexp p_creditfw ///
					existing ///
					) ///
			drop(p_educ_m p_grit_m p_sector1 p_ability_m p_satisf_m p_satexp_m p_abilityfw_m p_creditfw_m p_selfconfw1_m)  ///
			varlabels( _cons Constant ///
						b_totmark		"Business Plan score" ///
						existing		"Existing" ///
						p_female 		"Female" ///
						p_age			"Age" ///
						p_higheduc 		"Graduate Education" ///
						p_workabroad 	"Worked abroad" ///
						p_lot901		"Lottery choice" ///
						p_wealthindex	"Wealth" ///
						p_grit			"Grit" ///
						p_ability		"Ability" /// 
						p_sector31 		"Agriculture" ///
						p_manuf 		"Manufacture" ///
						p_sector19		"IT" ///
						p_retail		"Retail" ///
						p_selfconfw1	"Self-confidence" ///
						p_motivation 	"Motivation" /// 
						p_satisf 		"Happiness" ///
						p_satexp 		"Optimism" ///
						p_abilityfw		"Ability" ///
						p_creditfw 		"Credit" ///
							) /// 
				stats(N pval1 r2_a, labels("Sample Size" "P-value" "Adjusted R2") ///
								fmt(%6.0f %9.3f)) ///
				mtitles style(tex) ///
				modelwidth(6) varwidth(19) ///
				title({\b Table A4: Predicting Outcomes for Non-Winners Conditional on Operating a Firm }) ///
				addnotes ("Robust Standard Errors in parentheses. *, **, *** denote significance at the 10, 5, and 1 percent levels respectively") ///
				indicate("Regional Indicators = $REGION") ///
				star(* 0.10 ** 0.05 *** 0.01) ///
				label				
				
exit
