**********************************
**********************************
** ML Nigeria
** A4b - Prediction Logit Binary
**********************************
**********************************

/*
	READ ME
		set directory line 22
		run until the exit commant
		then run the desired specification
*/


capture log close
clear all
set more off
version 14.1 

*set directory
cd 
*load data
use "Data\MLNigeria_masterdata.dta", clear

*Note:
*Firms in control group who actually recived award (9 firms) dropped during data cleaning (dofile A1)
*Firms without business plan scores from RD sample dropped during data cleaning (dofile A1)
*Firms disqualified dropped during data cleaning (dofile A1)
		
**************************************
*Data Preparation
**************************************

	**************************************
	*Keep only relevant groups
	**************************************

		*Non-winners only since almost all winners are still operating a business after 3 years
		keep if (group==2|group==4)
		
		global depvar o_t_operatefirm
		keep if $depvar!=.
		sum $depvar

	**************************************
	*Global
	**************************************
	
		*Note: since we dropped the RD sample without business scores, there are no missings for these variables
		global BSCORE		b_maskill b_artic b_cap b_finsour b_finsust b_finviab b_jobcreate b_risk b_time b_unders 
							
		global GROUP		existing /*p_group4*/	
		
		global MCKENZIE 	p_higheduc p_educ_m ///
							p_workabroad /*p_workabroad_m never missing*/ ///
							p_lot901 /*p_lot905 never missing*/ ///
							p_wealthindex /*p_wealthindex_m never missing*/ ///
							p_grit p_grit_m ///
							p_ability p_ability_m ///
							p_sector31 /*agriculture*/ p_sector19 /*IT*/
							
		global FAFCHAMPS	p_selfconfw1 p_selfconfw1_m ///
							p_motivation /*p_motivation_m never missing*/ ///
							p_satisf p_satisf_m ///
							p_satexp  p_satexp_m ///
							p_abilityfw p_abilityfw_m ///
							p_creditfw p_creditfw_m ///
							p_retail 
							
		global REGION		p_region1 p_region2 p_region3 p_region4 p_region5
		global DEMOG		p_female ///
							p_age /*p_age_m never missing*/
		global COMMON		$REGION $DEMOG ///
							p_manuf p_sector1 /*missing sector*/

		*w/o gender
		global DEMOG2		/*p_female*/ p_age /*p_age_m never missing*/
		global COMMON2		$REGION $DEMOG2 ///
							p_manuf p_sector1 /*missing sector*/
		*w/o age
		global DEMOG3		p_female /*p_age*/ /*p_age_m never missing*/
		global COMMON3		$REGION $DEMOG3 ///
							p_manuf p_sector1 /*missing sector*/							

		*w/o age or gender
		global COMMON4		$REGION ///
							p_manuf p_sector1 /*missing sector*/							
							
	**************************************
	*Divide sample in trainig and hold-out samples
	**************************************	
	
		*sort data in random order
		set seed 1234
		gen random = uniform()
		sort random
		
		*Divide in 2 groups
		local size = _N * 0.8	
		qui gen train= (_n<=`size')
		qui gen holdout = (_n>`size')
		*tab train holdout, m col
		*1,077: 861 (79.94%) in train sample, 216 (20.06) in hold-out sample
						
	**************************************
	* Post-estimation program for binary dependent variable
	**************************************		
		
		capture program drop paccuracy
		program paccuracy
		
			*set threshold probability for predicting dropout
			local pbar = 0.5

			*predict probability of outcome variable
			predict probyhat
			sum probyhat, d
					
			*predict yhat 0/1
			qui gen yhat = 1 if probyhat>=`pbar' & !missing(probyhat)
			qui replace yhat = 0 if probyhat<`pbar' & !missing(probyhat)
					
			*compute % correct predictions (accuracy)
			qui generate accuracy = ($depvar == yhat) if !missing(yhat)
					
			di "Predicted using train sample"
			tab $depvar yhat if train==1, row
			sum accuracy if train==1
					
			di "Predicted using test sample"
			tab $depvar yhat if holdout==1, row
			sum accuracy if holdout==1 
			
			*boostrap out-of-sample performance
			preserve
				keep if holdout==1 
				bootstrap r(mean), reps(1000) seed(1111): sum accuracy
			restore
			
			*drop variables
			drop probyhat yhat accuracy
					 
		end		

exit		
		
**************************************
* Prediction
**************************************

	**************************************
	*Constant
	**************************************
	
		logit $depvar if train==1
		paccuracy	
		
	**************************************
	*Initial Score
	**************************************

		*no missings
		*codebook totalmark
		logit $depvar b_totmarkf $GROUP if train==1
		paccuracy		
		
	**************************************
	*Business Plan Total Score
	**************************************

		*no missings
		*codebook totalmarks
		logit $depvar b_totmark $GROUP if train==1
		paccuracy			
		
	**************************************
	*Business Plan Component Score
	**************************************
	
		logit $depvar $BSCORE $GROUP if train==1
		paccuracy				
	
	**************************************
	*Gender
	**************************************
	
		*no missings
		*codebook sex
		logit $depvar p_female $GROUP if train==1
		paccuracy				
					
	**************************************
	*Age
	**************************************

		*no missings
		*codebook age
		logit $depvar p_age $GROUP if train==1
		paccuracy				
				
	**************************************
	*Necessity Entrepreneurship
	**************************************

		*no missings
		*codebook rate_employment
		logit $depvar p_needjob $GROUP if train==1
		paccuracy				
				
	**************************************
	*Grit
	**************************************

		logit $depvar p_grit p_grit_m $GROUP if train==1
		paccuracy	
					
	**************************************
	*Backward Digit-span Recall
	**************************************
	
		logit $depvar p_digitspan p_digitspan_m $GROUP if train==1
		paccuracy	

	**************************************
	*Raven Test
	**************************************

		logit $depvar p_raven p_raven_m $GROUP if train==1
		paccuracy	
	
	**************************************
	*Registration time
	**************************************

		*no missings
		*codebook reg_time
		logit $depvar p_lateentrant $GROUP if train==1
		paccuracy		

	**************************************
	*McKenzie
	**************************************
	
		logit $depvar $COMMON $MCKENZIE $GROUP if train==1
		paccuracy
		
		*w/o gender
		logit $depvar $COMMON2 $MCKENZIE $GROUP if train==1
		paccuracy			

		*w/o age
		logit $depvar $COMMON3 $MCKENZIE $GROUP if train==1
		paccuracy			

		*w/o age or gender
		logit $depvar $COMMON4 $MCKENZIE $GROUP if train==1
		paccuracy			
		
	**************************************
	*Fafchamps-Woodruff
	**************************************

		logit $depvar $COMMON $FAFCHAMPS $GROUP if train==1
		paccuracy				
		
		*plus business scores
		*OLS
		regress $depvar $COMMON $FAFCHAMPS $GROUP b_totmark if train==1
		paccuracy	
		*Probit
		probit $depvar $COMMON $FAFCHAMPS $GROUP b_totmark if train==1
		paccuracy			
		*Logit
		logit $depvar $COMMON $FAFCHAMPS $GROUP b_totmark if train==1
		paccuracy
		
		*w/o gender
		logit $depvar $COMMON2 $FAFCHAMPS $GROUP if train==1
		paccuracy				
		
		*w/o age
		logit $depvar $COMMON3 $FAFCHAMPS $GROUP if train==1
		paccuracy				

		*w/o age or gender
		logit $depvar $COMMON4 $FAFCHAMPS $GROUP if train==1
		paccuracy				
		
exit
