**********************************
**********************************
** ML Nigeria
** A4c - Prediction Tail
**********************************
**********************************

/*
	READ ME
	Turn on/off: set directory line 22
		groups: lines 40-42
		outcomes: lines 45-47
		then run the desired specification
*/	

capture log close
clear all
set more off
version 14.1 

*set directory
cd 
*load data
use "Data\MLNigeria_masterdata.dta", clear

*Note:
*Firms in control group who actually recived award (9 firms) dropped during data cleaning (dofile A1)
*Firms without business plan scores from RD sample dropped during data cleaning (dofile A1)
*Firms disqualified dropped during data cleaning (dofile A1)
		
**************************************
*Data Preparation
**************************************

	**************************************
	*Keep only relevant groups
	**************************************

		*winners
		keep if (group==1|group==3)
		*non-winners
		*keep if (group==2|group==4)
		
		*continuous dep variable
		*global depvar o_t_totalemp1_IHS
		*global depvar o_t_sales_IHS
		global depvar o_t_profits_IHS
		keep if $depvar!=.
		sum $depvar
		
		*create upper tail variables
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		
		*descriptive stats
		sum up_success
		sum $depvar if up_success==0, d
		sum $depvar if up_success==1, d
		
	**************************************
	*Global
	**************************************
	
		*Note: since we dropped the RD sample without business scores, there are no missings for these variables
		global BSCORE		b_maskill b_artic b_cap b_finsour b_finsust b_finviab b_jobcreate b_risk b_time b_unders 
		
		*Group 1&3: control for winning status (p_group1) only when using business plan scores as predictors
		*Group 2&4: Do NOT control for RD group
		*global GROUP		existing /*p_group1*/ 			
		global GROUP		existing /*p_group4*/	

		global MCKENZIE 	p_higheduc p_educ_m ///
							p_workabroad /*p_workabroad_m never missing*/ ///
							p_lot901 /*p_lot905 never missing*/ ///
							p_wealthindex /*p_wealthindex_m never missing*/ ///
							p_grit p_grit_m ///
							p_ability p_ability_m ///
							p_sector31 /*agriculture*/ p_sector19 /*IT*/
							
		global FAFCHAMPS	p_selfconfw1 p_selfconfw1_m ///
							p_motivation /*p_motivation_m never missing*/ ///
							p_satisf p_satisf_m ///
							p_satexp  p_satexp_m ///
							p_abilityfw p_abilityfw_m ///
							p_creditfw p_creditfw_m ///
							p_retail 
							
		global REGION		p_region1 p_region2 p_region3 p_region4 p_region5
		global DEMOG		p_female ///
							p_age /*p_age_m never missing*/
		global COMMON		$REGION $DEMOG ///
							p_manuf p_sector1 /*missing sector*/
			
	**************************************
	*Divide sample in trainig and hold-out samples
	**************************************	
	
		*sort data in random order
		set seed 1234
		gen random = uniform()
		sort random
		
		*Divide in 2 groups
		local size = _N * 0.8	
		qui gen train= (_n<=`size')
		qui gen holdout = (_n>`size')
		*tab train holdout, m col
						
	**************************************
	* Post-estimation program 
	**************************************	
	
		capture program drop bootmse
		program bootmse, rclass
			qui egen SSR = total(residual2)
			qui sum SSR
			local ssr = r(mean)
			qui count 
			local nobs = r(N)
			return scalar mse= `ssr' / `nobs'
			qui drop SSR
			macro drop ssr nobs
		end
		
		capture program drop pmse
		program pmse
					
			*predict yhat
			qui predict yhat
			sum yhat
			
			*check if some observations below min depvar (usually 0). If so, impute them.
			*save this as a different variable, since you want to do the ranking without imputations
			gen yhat2 = yhat
			qui sum $depvar if train==1
			replace yhat2 = r(min) if yhat2<r(min)
			*check for extremely abnormal predictions
			qui sum $depvar if train==1
			local yhatmax = 2*r(max)
			sum yhat2
			if r(max)>`yhatmax' {
				replace yhat2 = `yhatmax' if yhat2>`yhatmax'
				sum yhat2
				di ""
				di "NOTE: Prediction outliers imputed"
				di ""
				}						
			
			*gen residual^2
			qui gen residual2 = ($depvar - yhat2)^2
			
			*number observations
			qui count if train==1 & $depvar!=.
			local train_n = r(N)
			qui count if holdout==1 & $depvar!=.
			local holdout_n = r(N)
				
			*train MSE	
			qui egen train_SSR = total(residual2) if !missing($depvar) & train==1
			qui sum train_SSR
			local train_mse= r(mean) / `train_n'
			di "The train MSE is " round(`train_mse', 0.01)

			*train r2
			qui corr $depvar yhat2 if train==1
			local train_r2 = r(rho)^2
			di "The train R^2 is " round(`train_r2'*100, 0.1)
			
			*holdout r2
			qui corr $depvar yhat2 if holdout==1
			local holdout_r2 = r(rho)^2
			di "The holdout R^2 is " round(`holdout_r2'*100, 0.1)
			
			*holdout MSE	
			qui egen holdout_SSR = total(residual2) if !missing($depvar) & holdout==1
			qui sum holdout_SSR
			local holdout_mse= r(mean) / `holdout_n'
			di "The holdout MSE is " round(`holdout_mse', 0.01)
			
			preserve
				keep if holdout==1
				*check thta bootmse provides the same average mse
					*bootmse
					*return list
				bootstrap r(mse), reps(1000) seed(1111): bootmse
			restore
			
			drop yhat2 residual2 train_SSR holdout_SSR
			macro drop train_n holdout_n train_mse holdout_r2 holdout_mse train_r2
		
		end
		
		capture program drop bootaccu
		program bootaccu, rclass
			qui count 
			local holdout10 = round(r(N)*0.1)
			sort yhat, stable
			gen tyhatb = 0
			replace tyhatb = 1 in -`holdout10'/L
			qui generate accuracyb = (up_success == tyhatb) if !missing(tyhatb) 
			qui sum accuracyb 
			return scalar accu= r(mean)
			qui drop tyhatb accuracyb
			macro drop holdout10
		end

	
		capture program drop paccuracy_tail
		program paccuracy_tail
				
			*get the number equivalent to 10% sample
			qui count if train==1 
			local train10 = round(r(N)*0.1)
			qui count if holdout==1 
			local holdout10 = round(r(N)*0.1)
							
			*predict yhat 0/1 for tail
			*Take the top 10% of predicted levels and call them predicted 1s, and call the rest predicted 0s
			*and then compare them to the truth to assess accuracy.
			
			di "Predicted using train sample"
			*Note: Without the [sort ... ,stable] option, the ordering of observations with equal values of varlist is randomized.
			sort train yhat, stable
			gen tyhat = 0 if train==1
			replace tyhat = 1 in -`train10'/L
			*Accuracy
			qui generate accuracy = (up_success == tyhat) if !missing(tyhat) & train==1
			tab up_success tyhat if train==1, row
			sum accuracy if train==1
			local train_accuracy= r(mean)
			di "Accuracy in train sample: " round(`train_accuracy'*100, 0.1)
			*Recall
			qui sum accuracy if train==1 & up_success==1
			local train_recall= r(mean)
			di "Recall in train sample: " round(`train_recall'*100, 0.1)
			drop tyhat accuracy
					
			di "Predicted using holdout sample"
			sort holdout yhat, stable
			gen tyhat = 0 if holdout==1
			replace tyhat = 1 in -`holdout10'/L
			*Accuracy
			qui generate accuracy = (up_success == tyhat) if !missing(tyhat) & holdout==1
			tab up_success tyhat if holdout==1, row
			sum accuracy if holdout==1 
			local holdout_accuracy= r(mean)
			di "Accuracy in holdout sample: " round(`holdout_accuracy'*100, 0.1)
			*Recall
			qui sum accuracy if holdout==1 & up_success==1
			local holdout_recall= r(mean)
			di "Recall in holdout sample: " round(`holdout_recall'*100, 0.1)

			*boostrap out-of-sample performance
			preserve
				keep if holdout==1
				*check thta bootaccu provides the same accuracy
					*bootaccu
					*return list
				bootstrap r(accu), reps(1000) seed(1111): bootaccu
			restore
		
			*drop variables
			drop tyhat accuracy
					 
		end		

exit		
		
**************************************
* Prediction
**************************************

	**************************************
	*Constant
	**************************************
	
		regress $depvar if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
	**************************************
	*Initial Score
	**************************************

		*no missings
		*codebook totalmark
		
		*non-winners
		regress $depvar b_totmarkf $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
		*winners
		regress $depvar b_totmarkf $GROUP b_totaw b_totaw_m  if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
				
	**************************************
	*Business Plan Total Score
	**************************************

		*no missings
		*codebook totalmarks
		
		*non-winners
		regress $depvar b_totmark $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail

		*winners
		regress $depvar b_totmark $GROUP p_group1 b_totaw b_totaw_m if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
				
	**************************************
	*Business Plan Component Score
	**************************************
	
		*Non-winners
		regress $depvar $BSCORE $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
		*Winners
		regress $depvar $BSCORE $GROUP p_group1 b_totaw b_totaw_m if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail	

	**************************************
	*Gender
	**************************************
		
		*no missings
		*codebook sex
		regress $depvar p_female $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
			
	**************************************
	*Age
	**************************************
		
		*no missings
		*codebook age
		regress $depvar p_age $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
	**************************************
	*Necessity Entrepreneurship
	**************************************
		
		*no missings
		*codebook rate_employment
		regress $depvar p_needjob $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
	**************************************
	*Grit
	**************************************
		
		regress $depvar p_grit p_grit_m $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
			
	**************************************
	*Backward Digit-span Recall
	**************************************
		
		regress $depvar p_digitspan p_digitspan_m $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
	**************************************
	*Raven Test
	**************************************

		regress $depvar p_raven p_raven_m $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
	**************************************
	*Registration time
	**************************************
		
		*no missings
		*codebook reg_time
		regress $depvar p_lateentrant $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail

	**************************************
	*McKenzie
	**************************************
		
		regress $depvar $COMMON $MCKENZIE $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
	**************************************
	*Fafchamps-Woodruff
	**************************************
	
		regress $depvar $COMMON $FAFCHAMPS $GROUP if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
		*with Business scores
		*Non-winners
		regress $depvar $COMMON $FAFCHAMPS $GROUP b_totmark if train==1
		pmse
		paccuracy_tail
		*Winners
		regress $depvar $COMMON $FAFCHAMPS $GROUP b_totmark p_group1 b_totaw b_totaw_m if train==1
		pmse
		paccuracy_tail
		
		*add baseline employment as regressor 
		egen baseline_empl = rowtotal(	workers_with_no_qualifications workers_with_primary_education ///
										workers_with_secondary_education workers_with_tertiary_education) 
		gen baseline_empl_m = (	workers_with_no_qualifications==. & workers_with_primary_education==. ///
								& workers_with_secondary_education==. & workers_with_tertiary_education==.)
		regress $depvar $COMMON $FAFCHAMPS $GROUP baseline_empl baseline_empl_m if train==1
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
	
exit
