**********************************
**********************************
** ML Nigeria
** B1b - Prediction SVM Binary
**********************************
**********************************

/*
	READ ME
	Turn on/off: set directory line 22
		Only FaWo input (robustness check): lines 143-157
		predictions: lines 290-291
*/

capture log close
clear all
set more off
set matsize 800
version 14.1 

*set directory
cd 
*load data
use "Data\MLNigeria_masterdata.dta", clear
*log file
log using "Output\Predict_SVM_Surv", replace

*Note:
*Firms in control group who actually recived award (9 firms) dropped during data cleaning (dofile A1)
*Firms without business plan scores from RD sample dropped during data cleaning (dofile A1)
*Firms disqualified dropped during data cleaning (dofile A1)

**************************************
*Data Preparation
**************************************

	**************************************
	*Keep only relevant groups
	**************************************

		*non-winners
		keep if (group==2|group==4)
		
		global depvar o_t_operatefirm
		keep if $depvar!=.

	**************************************
	*Divide sample in trainig and hold-out samples
	**************************************	
	
		*sort data in random order
		set seed 1234
		gen random = uniform()
		sort random
		
		*Divide in 2 groups
		local size = _N * 0.8	
		qui gen train= (_n<=`size')
		qui gen holdout = (_n>`size')
		*tab train holdout, m col
		
	**************************************
	*Divide training sample in 5 folds
	**************************************

		************************
		*Divide training sample in 5 groups
		************************	
	
			count if train==1
			local size2 = `r(N)'/5

			qui generate foldc=0 if train==1
			qui replace foldc=1 if _n>`size2' & train==1
			qui replace foldc=2 if _n>`size2'*2 & train==1
			qui replace foldc=3 if _n>`size2'*3 & train==1
			qui replace foldc=4 if _n>`size2'*4 & train==1

			tab foldc, gen(fold)
			*tab foldc train, m
			*holdout sample not in  the 5 folds, as expected
			*tab foldc holdout, m

		************************
		*Folds
		************************
		
			*Fold A
			gen byte trainA = (fold2==1 | fold3==1 | fold4==1 | fold5==1)
			gen byte testA = (fold1==1)
		
			*FoldB
			gen byte trainB = (fold1==1| fold3==1 | fold4==1 | fold5==1)
			gen byte testB = (fold2==1)
			
			*FoldC
			gen byte trainC = (fold1==1 | fold2==1| fold4==1 | fold5==1)
			gen byte testC = (fold3==1)
			
			*Fold D
			gen byte trainD = (fold1==1 | fold2==1 | fold3==1| fold5==1)
			gen byte testD = (fold4==1)
			
			*Fold E
			gen byte trainE = (fold1==1 | fold2==1 | fold3==1 | fold4==1)
			gen byte testE = (fold5==1)
		
	**************************************
	*Drop predictors that are always zero
	**************************************
	
		unab pred0: p_*
		global PRED0	`pred0'
*		*NOTE: FOR THE MAIN TABLE, DO NOT INCLUDE BUSINESS SCORES IN THE INPUTS
		*unab bus0: b_*
		*global PRED0	`pred0' `bus0'
		
		foreach var of global PRED0 {
			qui sum `var' if train==1 
			if r(mean)==0 & r(sd)==0 {
				di "`var'"
				drop `var'
			}	
		}
	
		*FOR GROUP 2 AND 4
		*drop also missing variable indicators related to these variables (only for bussiness name, the others were created from tab, gen so they are fine)
		*already dropped in replication file
		*drop p_bussn_m p_bussnb_m p_bussnc_m p_mask_m p_mgive_m 
		*drop b_totaw_m

	**************************************
	*Global
	**************************************
	
		unab individualpredictors: p_*
		global PREDICTOR 	`individualpredictors' existing
*		*NOTE: FOR THE MAIN TABLE, DO NOT INCLUDE BUSINESS SCORES IN THE INPUTS
		*unab businessplan: b_*
		*global PREDICTOR 	`individualpredictors' `businessplan' existing

/*
		*robustness check: use only FaWo inputs
		global GROUP		existing /*p_group4*/	
		global FAFCHAMPS	p_selfconfw1 p_selfconfw1_m ///
							p_motivation /*p_motivation_m never missing*/ ///
							p_satisf p_satisf_m ///
							p_satexp  p_satexp_m ///
							p_abilityfw p_abilityfw_m ///
							p_creditfw p_creditfw_m ///
							p_retail 
		global REGION		p_region1 p_region2 p_region3 p_region4 p_region5
		global DEMOG		p_female ///
							p_age /*p_age_m never missing*/
		global COMMON		$REGION $DEMOG ///
							p_manuf p_sector1 /*missing sector*/
		global PREDICTOR $COMMON $FAFCHAMPS $GROUP
*/		
		
	**************************************
	*Keep only relevant variables
	**************************************		
		
		keep uid group o_* $PREDICTOR random train* test* holdout 
		qui compress
		*count predictors
		unab countvars : $PREDICTOR
		di `: word count `countvars''
		
		*Following Mullainathan & Spiess (2017), do not drop collinear variables
		*qui _rmcoll $PREDICTOR, forcedrop
		*global PREDICTOR `r(varlist)'
				
	**************************************
	*Scale Regressors
	**************************************	
	
		*get min and max from the train sample only (as stressed in Mullainathan & Spiess, 2017)
		foreach var of global PREDICTOR {
			*Note: this do not change dummy variables: you subtract zero and divide by 1
			qui sum `var' if train==1
			qui replace `var' = (`var'-r(min))/(r(max)-r(min))
			}
				
	**************************************
	* Check no missing values
	**************************************	
	
		*check all have same number of obs as depvar
		qui sum $depvar if train==1
		local Ncheck = r(N)
		
		foreach var of global PREDICTOR {
			qui sum `var' if train==1
			if r(N)!=`Ncheck' {
				di "`var'"
				_exit
				}
		}		
	
*exit	
		
****************************************************************************************************************************************************************		
****************************************************************************************************************************************************************		
****************************************************************************************************************************************************************		

**************************************
* SVM
**************************************

	*sample size
	qui sum $depvar
	local Ncheck = r(N)
	*Choose best parameters with grid-search 
	local minerr=0
	foreach fkernel in rbf /*sigmoid*/ {
		foreach c of numlist 5e-03 1e-02 5e-02 0.1 0.5 1 5 10 50 100 500 1e+03 5e+03 1e+04 5e+04 1e+05 {
			foreach gamma of numlist 5e-07 1e-06 5e-06 1e-05 5e-05 1e-04 5e-04 1e-03 5e-03 1e-02 5e-02 0.1 .05 1 5 10 {
				global avaccu = 0					   
				foreach fold in A B C D E {
			
					*SVM
					di "Fold:`fold'"
					display "Current starting values: Kernel=`fkernel', C=`c', Gamma=`gamma'"
					qui sort random, stable
					qui svmachines $depvar $PREDICTOR if train`fold'==1, c(`c') gamma(`gamma') type(svc) kernel(`fkernel')				
					
					*prediction
					qui predict yhat
					*check same number of obs
					qui sum yhat
					if r(N)!=`Ncheck' {
						_exit
						}
					
					*accuracy
					qui generate accuracy = ($depvar == yhat) if !missing(yhat)
					qui sum accuracy if test`fold'==1 
					local accuracy= r(mean)
					di "Accuracy in test sample in fold `fold' is" `accuracy'
					global avaccu = $avaccu + `accuracy'
					
					*drop variables
					qui drop yhat accuracy
					qui macro drop accuracy 

					}
					
					global avaccu = $avaccu *100 / 5
					di "The average Accuracy for Kernel=`fkernel', C=`c', Gamma=`gamma' in the 5-fold CV is " round($avaccu, 0.1)
					
					*max accuracy rate
					if $avaccu>`minerr' {
						local minerr= $avaccu
						display "The new highest CV accuracy rate is " `minerr'
						local bestKernel `fkernel'
						local bestC = `c'
						local bestGamma = `gamma'
						display "Current best values: Kernel=`bestKernel', C=`bestC', Gamma=`bestGamma'"
						}
						
			}
		}
	}	

	*Best parameters
	display "Chosen starting values: Kernel=`bestKernel', C=`bestC', Gamma=`bestGamma'" 
	
	*SVM with best parameters
	sort random, stable
	qui svmachines $depvar $PREDICTOR if train==1, c(`bestC') gamma(`bestGamma') type(svc) kernel(`bestKernel')  
	qui predict yhat
	qui gen accuracy = ($depvar == yhat) if !missing(yhat)

	*Train
	tab $depvar yhat if train==1, row
	sum accuracy if train==1
		
	*Hold-out sample
	tab $depvar yhat if holdout==1, row
	sum accuracy if holdout==1

	*boostrap out-of-sample performance
	preserve
		keep if holdout==1 
		bootstrap r(mean), reps(1000) seed(1111): sum accuracy
	restore
	
	*save dataset 	
	rename yhat SVM_Su24
	save "SVMSu24.dta"	

log close	
exit
