**********************************
**********************************
** ML Nigeria
** B4b - Prediction Elastic Net Binary
**********************************
**********************************

/*
	READ ME
	Turn on/off or rename: set directory line 23
		log file name: line 27
		predictions:276-277
*/


capture log close
clear all
set more off
set matsize 800
version 14.1 

*set directory
cd 
*load data
use "Data\MLNigeria_masterdata.dta", clear
*log file
log using "Output\Predict_ENet_Surv", replace

*Note:
*Firms in control group who actually recived award (9 firms) dropped during data cleaning (dofile A1)
*Firms without business plan scores from RD sample dropped during data cleaning (dofile A1)
*Firms disqualified dropped during data cleaning (dofile A1)

**************************************
*Data Preparation
**************************************

	**************************************
	*Keep only relevant groups
	**************************************

		*non-winners
		keep if (group==2|group==4)
		
		global depvar o_t_operatefirm
		keep if $depvar!=.

	**************************************
	*Divide sample in trainig and hold-out samples
	**************************************	
	
		*sort data in random order
		set seed 1234
		gen random = uniform()
		sort random
		
		*Divide in 2 groups
		local size = _N * 0.8	
		qui gen train= (_n<=`size')
		qui gen holdout = (_n>`size')
		*tab train holdout, m col
		
	**************************************
	*Divide training sample in 5 folds
	**************************************

		************************
		*Divide training sample in 5 groups
		************************	
	
			count if train==1
			local size2 = `r(N)'/5

			qui generate foldc=0 if train==1
			qui replace foldc=1 if _n>`size2' & train==1
			qui replace foldc=2 if _n>`size2'*2 & train==1
			qui replace foldc=3 if _n>`size2'*3 & train==1
			qui replace foldc=4 if _n>`size2'*4 & train==1

			tab foldc, gen(fold)
			*tab foldc train, m
			*holdout sample not in  the 5 folds, as expected
			*tab foldc holdout, m

		************************
		*Folds
		************************
		
			*Fold A
			gen byte trainA = (fold2==1 | fold3==1 | fold4==1 | fold5==1)
			gen byte testA = (fold1==1)
		
			*FoldB
			gen byte trainB = (fold1==1| fold3==1 | fold4==1 | fold5==1)
			gen byte testB = (fold2==1)
			
			*FoldC
			gen byte trainC = (fold1==1 | fold2==1| fold4==1 | fold5==1)
			gen byte testC = (fold3==1)
			
			*Fold D
			gen byte trainD = (fold1==1 | fold2==1 | fold3==1| fold5==1)
			gen byte testD = (fold4==1)
			
			*Fold E
			gen byte trainE = (fold1==1 | fold2==1 | fold3==1 | fold4==1)
			gen byte testE = (fold5==1)
		
	**************************************
	*Drop predictors that are always zero
	**************************************
	
		unab pred0: p_*
		global PRED0	`pred0'
*		*NOTE: FOR THE MAIN TABLE, DO NOT INCLUDE BUSINESS SCORES IN THE INPUTS
		*unab bus0: b_*
		*global PRED0	`pred0' `bus0'
		
		foreach var of global PRED0 {
			qui sum `var' if train==1 
			if r(mean)==0 & r(sd)==0 {
				di "`var'"
				drop `var'
			}	
		}
	
		*FOR GROUP 2 AND 4
		*drop also missing variable indicators related to these variables (only for bussiness name, the others were created from tab, gen so they are fine)
		*already dropped in replication file
		*drop p_bussn_m p_bussnb_m p_bussnc_m p_mask_m p_mgive_m 
		*drop b_totaw_m
		
	**************************************
	*Global
	**************************************
	
		unab individualpredictors: p_*
		global PREDICTOR 	`individualpredictors' existing
*		*NOTE: FOR THE MAIN TABLE, DO NOT INCLUDE BUSINESS SCORES IN THE INPUTS
		*unab businessplan: b_*
		*global PREDICTOR 	`individualpredictors' `businessplan' existing
				
	**************************************
	*Keep only relevant variables
	**************************************		
		
		keep uid group o_* $PREDICTOR random train* test* holdout 
		qui compress
		*count predictors
		unab countvars : $PREDICTOR
		di `: word count `countvars''
		
		*Following Mullainathan & Spiess (2017), do not drop collinear variables
		*qui _rmcoll $PREDICTOR, forcedrop
		*global PREDICTOR `r(varlist)'
				
	**************************************
	*Scale Regressors
	**************************************	
	
		*get min and max from the train sample only (as stressed in Mullainathan & Spiess, 2017)
		foreach var of global PREDICTOR {
			*Note: this do not change dummy variables: you subtract zero and divide by 1
			qui sum `var' if train==1
			qui replace `var' = (`var'-r(min))/(r(max)-r(min))
			}
				
	**************************************
	* Check no missing values
	**************************************	
	
		*check all have same number of obs as depvar
		qui sum $depvar if train==1
		local Ncheck = r(N)
		
		foreach var of global PREDICTOR {
			qui sum `var' if train==1
			if r(N)!=`Ncheck' {
				di "`var'"
				_exit
				}
		}		
	
*exit	
		
****************************************************************************************************************************************************************		
****************************************************************************************************************************************************************		
****************************************************************************************************************************************************************		

**************************************
* Elastic Net
**************************************

	*Choose best parameters with grid-search 
	local minerr=0
	foreach talpha of numlist 0(0.25)1 {
		foreach tlambda of numlist 0 1e-12 1e-11 5e-11 1e-10 5e-10 1e-09 5e-09 1e-08 5e-08 ///
								1e-07 2e-07 3e-07 4e-07 5e-07 6e-07 7e-07 8e-07 9e-07 ///
								1e-06 2e-06 3e-06 4e-06 5e-06 6e-06 7e-06 8e-06 9e-06 ///
								1e-05 2e-05 3e-05 4e-05 5e-05 6e-05 7e-05 8e-05 9e-05 ///
								1e-04 2e-04 3e-04 4e-04 5e-04 6e-04 7e-04 8e-04 9e-04 ///
								1e-03 2e-03 3e-03 4e-03 5e-03 6e-03 7e-03 8e-03 9e-03 ///
								1e-02 2e-02 3e-02 4e-02 5e-02 6e-02 7e-02 8e-02 9e-02 ///
								1e-01 5e-01 1 5 10 50 {
			global avaccu = 0					   
			foreach fold in A B C D E {
				
				*Elastic Net
				di "Fold:`fold'"
				display "Current starting value: Alpha=`talpha' Lambda=`tlambda' "
				sort random, stable
				qui elasticregress $depvar $PREDICTOR if train`fold'==1, lambda(`tlambda') alpha(`talpha')
				
				*prediction
				qui predict probyhat
				qui gen yhat = 1 if probyhat>=0.5 & !missing(probyhat)
				qui replace yhat = 0 if probyhat<0.5 & !missing(probyhat)
				
				*accuracy
				qui generate accuracy = ($depvar == yhat) if !missing(yhat)
				qui sum accuracy if test`fold'==1 
				local accuracy= r(mean)
				di "Accuracy in test sample in fold `fold' is" `accuracy'
				global avaccu = $avaccu + `accuracy'
				
				*drop variables
				qui drop probyhat yhat accuracy
				qui macro drop accuracy 

				}
				
				global avaccu = $avaccu *100 / 5
				di "The average Accuracy in the 5-fold CV is " round($avaccu, 0.1)
				
				*max accuracy rate
				if $avaccu>`minerr' {
					local minerr= $avaccu
					display "The new highest CV accuracy rate is " `minerr'
					local bestLambda = `tlambda'
					local bestAlpha = `talpha'
					display "Current best values: Alpha=`bestAlpha' Lambda=`bestLambda'"
					}
					
		}
	}	

	*Best parameters
	display "Chosen starting values: Alpha=`bestAlpha' Lambda=`bestLambda'"  
	
	*Elastic Net with best parameters
	sort random, stable
	qui elasticregress $depvar $PREDICTOR if train==1, lambda(`bestLambda') alpha(`bestAlpha')
	ereturn list
	
	*predictions
	qui predict probyhat
	qui gen yhat = 1 if probyhat>=0.5 & !missing(probyhat)
	qui replace yhat = 0 if probyhat<0.5 & !missing(probyhat)	
	qui gen accuracy = ($depvar == yhat) if !missing(yhat)

	*Train
	tab $depvar yhat if train==1, row
	sum accuracy if train==1
		
	*Hold-out sample
	tab $depvar yhat if holdout==1, row
	sum accuracy if holdout==1

	*boostrap out-of-sample performance
	preserve
		keep if holdout==1 
		bootstrap r(mean), reps(1000) seed(1111): sum accuracy
	restore
	
	*save dataset 	
	rename yhat ENet_Su24
	save "ENetSu24.dta"
	
log close	
exit
