**********************************
**********************************
** ML Nigeria
** B6 - Prediction ML Tail
**********************************
**********************************

/*
	READ ME
	set directory: line 23
	Turn on/off:
		run until the exit command
		then run the desired lines, e.g. 192-202 for LASSO Employment non-winners
*/

capture log close
clear all
set more off
set matsize 11000
version 14.1 

*set directory
cd 
*Note: the datasets used in this dofile were saved when running the dofiles B1, B2, B3

**************************************
*Programs
**************************************

		capture program drop bootmse
		program bootmse, rclass
			qui egen SSR = total(residual2)
			qui sum SSR
			local ssr = r(mean)
			qui count 
			local nobs = r(N)
			return scalar mse= `ssr' / `nobs'
			qui drop SSR
			macro drop ssr nobs
		end
		
		capture program drop pmse
		program pmse
		
			drop residual2
		
			*check if some observations below min depvar (usually 0). If so, impute them.
			*save this as a different variable, since you want to do the ranking without imputations
			gen yhat2 = yhat
			qui sum $depvar if train==1
			replace yhat2 = r(min) if yhat2<r(min)
			*check for extremely abnormal predictions
			qui sum $depvar if train==1
			local yhatmax = 2*r(max)
			sum yhat2
			if r(max)>`yhatmax' {
				replace yhat2 = `yhatmax' if yhat2>`yhatmax'
				sum yhat2
				di ""
				di "NOTE: Prediction outliers imputed"
				di ""
				}						
			
			*gen residual^2
			qui gen residual2 = ($depvar - yhat2)^2
			
			*number observations
			qui count if train==1 & $depvar!=.
			local train_n = r(N)
			qui count if holdout==1 & $depvar!=.
			local holdout_n = r(N)
				
			*train MSE	
			qui egen train_SSR = total(residual2) if !missing($depvar) & train==1
			qui sum train_SSR
			local train_mse= r(mean) / `train_n'
			di "The train MSE is " round(`train_mse', 0.01)

			*train r2
			qui corr $depvar yhat2 if train==1
			local train_r2 = r(rho)^2
			di "The new train R^2 is " round(`train_r2'*100, 0.1)
			
			*holdout r2
			qui corr $depvar yhat2 if holdout==1
			local holdout_r2 = r(rho)^2
			di "The holdout R^2 is " round(`holdout_r2'*100, 0.1)
			
			*holdout MSE	
			qui egen holdout_SSR = total(residual2) if !missing($depvar) & holdout==1
			qui sum holdout_SSR
			local holdout_mse= r(mean) / `holdout_n'
			di "The holdout MSE is " round(`holdout_mse', 0.01)
			
			preserve
				keep if holdout==1
				*check thta bootmse provides the same average mse
					*bootmse
					*return list
				bootstrap r(mse), reps(1000) seed(1111): bootmse
			restore
			
			drop yhat2 residual2 train_SSR holdout_SSR
			macro drop train_n holdout_n train_mse holdout_r2 holdout_mse train_r2
		
		end

		capture program drop bootaccu
		program bootaccu, rclass
			qui count 
			local holdout10 = round(r(N)*0.1)
			sort yhat, stable
			gen tyhatb = 0
			replace tyhatb = 1 in -`holdout10'/L
			qui generate accuracyb = (up_success == tyhatb) if !missing(tyhatb) 
			qui sum accuracyb 
			return scalar accu= r(mean)
			qui drop tyhatb accuracyb
			macro drop holdout10
		end

	
		capture program drop paccuracy_tail
		program paccuracy_tail
				
			*get the number equivalent to 10% sample
			qui count if train==1 
			local train10 = round(r(N)*0.1)
			qui count if holdout==1 
			local holdout10 = round(r(N)*0.1)
							
			*predict yhat 0/1 for tail
			*Take the top 10% of predicted levels and call them predicted 1s, and call the rest predicted 0s
			*and then compare them to the truth to assess accuracy.
			
			di "Predicted using train sample"
			*Note: Without the [sort ... ,stable] option, the ordering of observations with equal values of varlist is randomized.
			sort train yhat, stable
			gen tyhat = 0 if train==1
			replace tyhat = 1 in -`train10'/L
			*Accuracy
			qui generate accuracy = (up_success == tyhat) if !missing(tyhat) & train==1
			tab up_success tyhat if train==1, row
			sum accuracy if train==1
			local train_accuracy= r(mean)
			di "Accuracy in train sample: " round(`train_accuracy'*100, 0.1)
			*Recall
			qui sum accuracy if train==1 & up_success==1
			local train_recall= r(mean)
			di "Recall in train sample: " round(`train_recall'*100, 0.1)
			drop tyhat accuracy
					
			di "Predicted using holdout sample"
			sort holdout yhat, stable
			gen tyhat = 0 if holdout==1
			replace tyhat = 1 in -`holdout10'/L
			*Accuracy
			qui generate accuracy = (up_success == tyhat) if !missing(tyhat) & holdout==1
			tab up_success tyhat if holdout==1, row
			sum accuracy if holdout==1 
			local holdout_accuracy= r(mean)
			di "Accuracy in holdout sample: " round(`holdout_accuracy'*100, 0.1)
			*Recall
			qui sum accuracy if holdout==1 & up_success==1
			local holdout_recall= r(mean)
			di "Recall in holdout sample: " round(`holdout_recall'*100, 0.1)

			*boostrap out-of-sample performance
			preserve
				keep if holdout==1
				*check thta bootaccu provides the same accuracy
					*bootaccu
					*return list
				bootstrap r(accu), reps(1000) seed(1111): bootaccu
			restore
		
			*drop variables
			drop tyhat accuracy
					 
		end		

exit

**************************************
*Employment
**************************************
	
	*********
	*E24
	*********
		
		*LASSO
		use "LASSOEmpl24.dta", clear
		global depvar o_t_totalemp1_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename LASSO_Empl24 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail

		*SVM
		use "SVMEmpl24.dta", clear
		global depvar o_t_totalemp1_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename SVM_Empl24 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
		*Boosting
		use "BoostEmpl24.dta", clear
		global depvar o_t_totalemp1_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename Boost_Empl24 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
	*********
	*E13
	*********
		
		*LASSO
		use "LASSOEmpl13.dta", clear
		global depvar o_t_totalemp1_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename LASSO_Empl13 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail		

		*SVM
		use "SVMEmpl13.dta", clear
		global depvar o_t_totalemp1_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename SVM_Empl13 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
		*Boosting
		use "BoostEmpl13.dta", clear
		global depvar o_t_totalemp1_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename Boost_Empl13 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
**************************************
*Profits
**************************************

	*********
	*P24
	*********
		
		*LASSO
		use "LASSOProf24.dta", clear
		global depvar o_t_profits_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename LASSO_Prof24 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail

		*SVM
		use "SVMProf24.dta", clear
		global depvar o_t_profits_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename SVM_Prof24 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
		*Boosting
		use "BoostProf24.dta", clear
		global depvar o_t_profits_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename Boost_Prof24 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
	*********
	*P13
	*********
		
		*LASSO
		use "LASSOProf13.dta", clear
		global depvar o_t_profits_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename LASSO_Prof13 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail		

		*SVM
		use "SVMProf13.dta", clear
		global depvar o_t_profits_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename SVM_Prof13 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
		*Boosting
		use "BoostProf13.dta", clear
		global depvar o_t_profits_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename Boost_Prof13 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail

**************************************
*Sale
**************************************

	*********
	*S24
	*********
		
		*LASSO
		use "LASSOSale24.dta", clear
		global depvar o_t_sales_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename LASSO_Sale24 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail

		*SVM
		use "SVMSale24.dta", clear
		global depvar o_t_sales_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename SVM_Sale24 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
		*Boosting
		use "BoostSale24.dta", clear
		global depvar o_t_sales_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename Boost_Sale24 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
	*********
	*S13
	*********
		
		*LASSO
		use "LASSOSale13.dta", clear
		global depvar o_t_sales_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename LASSO_Sale13 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail		

		*SVM
		use "SVMSale13.dta", clear
		global depvar o_t_sales_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename SVM_Sale13 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
		*Boosting
		use "BoostSale13.dta", clear
		global depvar o_t_sales_IHS
		qui sum $depvar, d
		gen up_success = ($depvar >= r(p90)) if !missing($depvar)
		sum up_success
		rename Boost_Sale13 yhat
		*check if same results as main tables
		pmse
		*tail accuracy
		paccuracy_tail
		
exit
